@@ -148,6 +148,7 @@ static void call_received(SalOp *h){
 	LinphoneAddress *from_addr, *to_addr;
 	SalMediaDescription *md;
 	bool_t propose_early_media=lp_config_get_int(lc->config,"sip","incoming_calls_early_media",FALSE);
+	bool_t prevent_colliding_calls=lp_config_get_int(lc->config,"sip","prevent_colliding_calls",TRUE);
 	const char *ringback_tone=linphone_core_get_remote_ringback_tone (lc);
 	
 	/* first check if we can answer successfully to this invite */
@@ -176,7 +177,7 @@ static void call_received(SalOp *h){
 	from_addr=linphone_address_new(from);
 	to_addr=linphone_address_new(to);
 
-	if (already_a_call_with_remote_address(lc,from_addr) || already_a_call_pending(lc)){
+	if ((already_a_call_with_remote_address(lc,from_addr) && prevent_colliding_calls) || already_a_call_pending(lc)){
 		ms_warning("Receiving another call while one is ringing or initiated, refusing this one with busy message.");
 		sal_call_decline(h,SalReasonBusy,NULL);
 		sal_op_release(h);
@@ -532,6 +533,21 @@ static void call_failure(SalOp *op, SalError error, SalReason sr, const char *de
 					lc->vtable.display_status(lc,msg600);
 			break;
 			case SalReasonMedia:
+			//media_encryption_mandatory
+				if (call->params.media_encryption == LinphoneMediaEncryptionSRTP && 
+					!linphone_core_is_media_encryption_mandatory(lc)) {
+					int i;
+					ms_message("Outgoing call failed with SRTP (SAVP) enabled - retrying with AVP");
+					linphone_call_stop_media_streams(call);
+					/* clear SRTP local params */
+					call->params.media_encryption = LinphoneMediaEncryptionNone;
+					for(i=0; i<call->localdesc->nstreams; i++) {
+						call->localdesc->streams[i].proto = SalProtoRtpAvp;
+						memset(call->localdesc->streams[i].crypto, 0, sizeof(call->localdesc->streams[i].crypto));
+					}
+					linphone_core_start_invite(lc, call, NULL);
+					return;
+				}
 				msg=_("No common codecs");
 				if (lc->vtable.display_status)
 					lc->vtable.display_status(lc,msg);
