@@ -26,6 +26,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "lpconfig.h"
 #include "private.h"
 #include <ortp/event.h>
+#include <ortp/b64.h>
 
 
 #include "mediastreamer2/mediastream.h"
@@ -41,20 +42,29 @@ static MSWebCam *get_nowebcam_device(){
 }
 #endif
 
-LinphoneCore *linphone_call_get_core(const LinphoneCall *call){
-	return call->core;
+static bool_t generate_b64_crypto_key(int key_length, char* key_out) {
+	int b64_size;
+	uint8_t* tmp = (uint8_t*) malloc(key_length);			
+	if (ortp_crypto_get_random(tmp, key_length)!=0) {
+		ms_error("Failed to generate random key");
+		free(tmp);
+		return FALSE;
+	}
+	
+	b64_size = b64_encode((const char*)tmp, key_length, NULL, 0);
+	if (b64_size == 0) {
+		ms_error("Failed to b64 encode key");
+		free(tmp);
+		return FALSE;
+	}
+	key_out[b64_size] = '\0';
+	b64_encode((const char*)tmp, key_length, key_out, 40);
+	free(tmp);
+	return TRUE;
 }
 
-static const char* get_hexa_zrtp_identifier(LinphoneCore *lc){
-	const char *confZid=lp_config_get_string(lc->config,"rtp","zid",NULL);
-	if (confZid != NULL) {
-		return confZid;
-	} else {
-        char zidstr[128];
-        snprintf(zidstr,sizeof(zidstr),"%x-%x-%x",rand(),rand(),rand());
-		lp_config_set_string(lc->config,"rtp","zid",zidstr);
-		return lp_config_get_string(lc->config,"rtp","zid",NULL);
-	}
+LinphoneCore *linphone_call_get_core(const LinphoneCall *call){
+	return call->core;
 }
 
 const char* linphone_call_get_authentication_token(LinphoneCall *call){
@@ -64,7 +74,8 @@ const char* linphone_call_get_authentication_token(LinphoneCall *call){
 bool_t linphone_call_get_authentication_token_verified(LinphoneCall *call){
 	return call->auth_token_verified;
 }
-bool_t linphone_call_are_all_streams_encrypted(LinphoneCall *call) {
+
+static bool_t linphone_call_are_all_streams_encrypted(LinphoneCall *call) {
 	// Check ZRTP encryption in audiostream
 	if (!call->audiostream_encrypted) {
 		return FALSE;
@@ -82,14 +93,17 @@ bool_t linphone_call_are_all_streams_encrypted(LinphoneCall *call) {
 }
 
 void propagate_encryption_changed(LinphoneCall *call){
-	if (call->core->vtable.call_encryption_changed == NULL) return;
-
+	LinphoneCore *lc=call->core;
 	if (!linphone_call_are_all_streams_encrypted(call)) {
 		ms_message("Some streams are not encrypted");
-		call->core->vtable.call_encryption_changed(call->core, call, FALSE, call->auth_token);
+		call->current_params.media_encryption=LinphoneMediaEncryptionNone;
+		if (lc->vtable.call_encryption_changed)
+			lc->vtable.call_encryption_changed(call->core, call, FALSE, call->auth_token);
 	} else {
 		ms_message("All streams are encrypted");
-		call->core->vtable.call_encryption_changed(call->core, call, TRUE, call->auth_token);
+		call->current_params.media_encryption=LinphoneMediaEncryptionZRTP;
+		if (lc->vtable.call_encryption_changed)
+			lc->vtable.call_encryption_changed(call->core, call, TRUE, call->auth_token);
 	}
 }
 
@@ -109,7 +123,7 @@ static void linphone_call_audiostream_encryption_changed(void *data, bool_t encr
 
 	LinphoneCall *call = (LinphoneCall *)data;
 	call->audiostream_encrypted=encrypted;
-
+	
 	if (encrypted && call->core->vtable.display_status != NULL) {
 		snprintf(status,sizeof(status)-1,_("Authentication token is %s"),call->auth_token);
 		 call->core->vtable.display_status(call->core, status);
@@ -124,7 +138,6 @@ static void linphone_call_audiostream_encryption_changed(void *data, bool_t encr
 	if (params->has_video) {
 		ms_message("Trying to enable encryption on video stream");
 		OrtpZrtpParams params;
-		params.zid=get_hexa_zrtp_identifier(call->core);
 		params.zid_file=NULL; //unused
 		video_stream_enable_zrtp(call->videostream,call->audiostream,&params);
 	}
@@ -143,6 +156,21 @@ static void linphone_call_audiostream_auth_token_ready(void *data, const char* a
 	ms_message("Authentication token is %s (%s)", auth_token, verified?"verified":"unverified");
 }
 
+void linphone_call_set_authentication_token_verified(LinphoneCall *call, bool_t verified){
+	if (call->audiostream==NULL){
+		ms_error("linphone_call_set_authentication_token_verified(): No audio stream");
+	}
+	if (call->audiostream->ortpZrtpContext==NULL){
+		ms_error("linphone_call_set_authentication_token_verified(): No zrtp context.");
+	}
+	if (!call->auth_token_verified && verified){
+		ortp_zrtp_sas_verified(call->audiostream->ortpZrtpContext);
+	}else if (call->auth_token_verified && !verified){
+		ortp_zrtp_sas_reset_verified(call->audiostream->ortpZrtpContext);
+	}
+	call->auth_token_verified=verified;
+	propagate_encryption_changed(call);
+}
 
 static MSList *make_codec_list(LinphoneCore *lc, const MSList *codecs, int bandwidth_limit){
 	MSList *l=NULL;
@@ -165,6 +193,7 @@ static MSList *make_codec_list(LinphoneCore *lc, const MSList *codecs, int bandw
 static SalMediaDescription *_create_local_media_description(LinphoneCore *lc, LinphoneCall *call, unsigned int session_id, unsigned int session_ver){
 	MSList *l;
 	PayloadType *pt;
+	int i;
 	const char *me=linphone_core_get_identity(lc);
 	LinphoneAddress *addr=linphone_address_new(me);
 	const char *username=linphone_address_get_username (addr);
@@ -180,7 +209,8 @@ static SalMediaDescription *_create_local_media_description(LinphoneCore *lc, Li
 	/*set audio capabilities */
 	strncpy(md->streams[0].addr,call->localip,sizeof(md->streams[0].addr));
 	md->streams[0].port=call->audio_port;
-	md->streams[0].proto=SalProtoRtpAvp;
+	md->streams[0].proto=(call->params.media_encryption == LinphoneMediaEncryptionSRTP) ? 
+		SalProtoRtpSavp : SalProtoRtpAvp;
 	md->streams[0].type=SalAudio;
 	md->streams[0].ptime=lc->net_conf.down_ptime;
 	l=make_codec_list(lc,lc->codecs_conf.audio_codecs,call->params.audio_bw);
@@ -192,11 +222,26 @@ static SalMediaDescription *_create_local_media_description(LinphoneCore *lc, Li
 	if (call->params.has_video){
 		md->nstreams++;
 		md->streams[1].port=call->video_port;
-		md->streams[1].proto=SalProtoRtpAvp;
+		md->streams[1].proto=md->streams[0].proto;
 		md->streams[1].type=SalVideo;
 		l=make_codec_list(lc,lc->codecs_conf.video_codecs,0);
 		md->streams[1].payloads=l;
 	}
+	
+	for(i=0; i<md->nstreams; i++) {
+		if (md->streams[i].proto == SalProtoRtpSavp) {
+			md->streams[i].crypto[0].tag = 1;
+			md->streams[i].crypto[0].algo = AES_128_SHA1_80;
+			if (!generate_b64_crypto_key(30, md->streams[i].crypto[0].master_key))
+				md->streams[i].crypto[0].algo = 0;
+			md->streams[i].crypto[1].tag = 2;
+			md->streams[i].crypto[1].algo = AES_128_SHA1_32;
+			if (!generate_b64_crypto_key(30, md->streams[i].crypto[1].master_key))
+				md->streams[i].crypto[1].algo = 0;
+			md->streams[i].crypto[2].algo = 0;
+		}
+	}
+	
 	linphone_address_destroy(addr);
 	return md;
 }
@@ -286,7 +331,7 @@ LinphoneCall * linphone_call_new_outgoing(struct _LinphoneCore *lc, LinphoneAddr
 		linphone_core_run_stun_tests(call->core,call);
 	discover_mtu(lc,linphone_address_get_domain (to));
 	if (params->referer){
-		sal_call_set_referer (call->op,params->referer->op);
+		sal_call_set_referer(call->op,params->referer->op);
 	}
 	return call;
 }
@@ -304,7 +349,7 @@ LinphoneCall * linphone_call_new_incoming(LinphoneCore *lc, LinphoneAddress *fro
 		/*the following sends an option request back to the caller so that
 		 we get a chance to discover our nat'd address before answering.*/
 		call->ping_op=sal_op_new(lc->sal);
-		from_str=linphone_address_as_string(from);
+		from_str=linphone_address_as_string_uri_only(from);
 		sal_op_set_route(call->ping_op,sal_op_get_network_origin(call->op));
 		sal_op_set_user_pointer(call->ping_op,call);
 		sal_ping(call->ping_op,linphone_core_find_best_identity(lc,from,NULL),from_str);
@@ -314,7 +359,7 @@ LinphoneCall * linphone_call_new_incoming(LinphoneCore *lc, LinphoneAddress *fro
 	linphone_address_clean(from);
 	linphone_core_get_local_ip(lc,linphone_address_get_domain(from),call->localip);
 	linphone_call_init_common(call, from, to);
-	call->params.has_video=linphone_core_video_enabled(lc);
+	linphone_core_init_default_params(lc, &call->params);
 	call->localdesc=create_local_media_description (lc,call);
 	call->camera_active=call->params.has_video;
 	if (linphone_core_get_firewall_policy(call->core)==LinphonePolicyUseStun)
@@ -350,7 +395,7 @@ static void linphone_call_set_terminated(LinphoneCall *call){
 	if (ms_list_size(lc->calls)==0)
 		linphone_core_notify_all_friends(lc,lc->presence_mode);
 
-	linphone_core_conference_check_uninit(&lc->conf_ctx);
+	linphone_core_conference_check_uninit(lc);
 	if (call->ringing_beep){
 		linphone_core_stop_dtmf(lc);
 		call->ringing_beep=FALSE;
@@ -408,7 +453,7 @@ void linphone_call_set_state(LinphoneCall *call, LinphoneCallState cstate, const
 		if (call->state==LinphoneCallEnd || call->state==LinphoneCallError){
 			if (cstate!=LinphoneCallReleased){
 				ms_warning("Spurious call state change from %s to %s, ignored.",linphone_call_state_to_string(call->state),
-		           linphone_call_state_to_string(cstate));
+				   linphone_call_state_to_string(cstate));
 				return;
 			}
 		}
@@ -421,13 +466,14 @@ void linphone_call_set_state(LinphoneCall *call, LinphoneCallState cstate, const
 		}
 		if (cstate==LinphoneCallEnd || cstate==LinphoneCallError){
              if (call->reason==LinphoneReasonDeclined){
-                 call->log->status=LinphoneCallDeclined;
-             }
-            linphone_call_set_terminated (call);
+				call->log->status=LinphoneCallDeclined;
+			}
+			linphone_call_set_terminated (call);
+		}
+		if (cstate == LinphoneCallConnected) {
+			call->log->status=LinphoneCallSuccess;
+			call->media_start_time=time(NULL);
 		}
-        if (cstate == LinphoneCallConnected) {
-            call->log->status=LinphoneCallSuccess;
-        }
 
 		if (lc->vtable.call_state_changed)
 			lc->vtable.call_state_changed(lc,call,cstate,message);
@@ -679,6 +725,15 @@ bool_t linphone_call_params_video_enabled(const LinphoneCallParams *cp){
 	return cp->has_video;
 }
 
+enum LinphoneMediaEncryption linphone_call_params_get_media_encryption(const LinphoneCallParams *cp) {
+	return cp->media_encryption;
+}
+
+void linphone_call_params_set_media_encryption(LinphoneCallParams *cp, enum LinphoneMediaEncryption e) {
+	cp->media_encryption = e;
+}
+
+
 /**
  * Enable sending of real early media (during outgoing calls).
 **/
@@ -790,8 +845,11 @@ void linphone_call_init_media_streams(LinphoneCall *call){
 		audio_stream_enable_noise_gate(audiostream,enabled);
 	}
 
-	if (lc->a_rtp)
-		rtp_session_set_transports(audiostream->session,lc->a_rtp,lc->a_rtcp);
+	if (lc->rtptf){
+		RtpTransport *artp=lc->rtptf->audio_rtp_func(lc->rtptf->audio_rtp_func_data, call->audio_port);
+		RtpTransport *artcp=lc->rtptf->audio_rtcp_func(lc->rtptf->audio_rtcp_func_data, call->audio_port+1);
+		rtp_session_set_transports(audiostream->session,artp,artcp);
+	}
 
 	call->audiostream_app_evq = ortp_ev_queue_new();
 	rtp_session_register_event_queue(audiostream->session,call->audiostream_app_evq);
@@ -803,8 +861,11 @@ void linphone_call_init_media_streams(LinphoneCall *call){
 	if( lc->video_conf.displaytype != NULL)
 		video_stream_set_display_filter_name(call->videostream,lc->video_conf.displaytype);
 	video_stream_set_event_callback(call->videostream,video_stream_event_cb, call);
-	if (lc->v_rtp)
-		rtp_session_set_transports(call->videostream->session,lc->v_rtp,lc->v_rtcp);
+	if (lc->rtptf){
+		RtpTransport *vrtp=lc->rtptf->video_rtp_func(lc->rtptf->video_rtp_func_data, call->video_port);
+		RtpTransport *vrtcp=lc->rtptf->video_rtcp_func(lc->rtptf->video_rtcp_func_data, call->video_port+1);
+		rtp_session_set_transports(call->videostream->session,vrtp,vrtcp);
+	}
 	call->videostream_app_evq = ortp_ev_queue_new();
 	rtp_session_register_event_queue(call->videostream->session,call->videostream_app_evq);
 #ifdef TEST_EXT_RENDERER
@@ -984,12 +1045,25 @@ static bool_t linphone_call_sound_resources_available(LinphoneCall *call){
 	return !linphone_core_is_in_conference(lc) && 
 		(current==NULL || current==call);
 }
-
+static int find_crypto_index_from_tag(const SalSrtpCryptoAlgo crypto[],unsigned char tag) {
+	int i;
+	for(i=0; i<SAL_CRYPTO_ALGO_MAX; i++) {
+		if (crypto[i].tag == tag) {
+			return i;
+		}
+	}
+	return -1;
+}
 static void linphone_call_start_audio_stream(LinphoneCall *call, const char *cname, bool_t muted, bool_t send_ringbacktone, bool_t use_arc){
 	LinphoneCore *lc=call->core;
 	int jitt_comp=lc->rtp_conf.audio_jitt_comp;
 	int used_pt=-1;
+	/* look for savp stream first */
 	const SalStreamDescription *stream=sal_media_description_find_stream(call->resultdesc,
+	    					SalProtoRtpSavp,SalAudio);
+	/* no savp audio stream, use avp */
+	if (!stream)
+		stream=sal_media_description_find_stream(call->resultdesc,
 	    					SalProtoRtpAvp,SalAudio);
 
 	if (stream && stream->dir!=SalStreamInactive && stream->port!=0){
@@ -1066,10 +1140,23 @@ static void linphone_call_start_audio_stream(LinphoneCall *call, const char *cna
 				setup_ring_player(lc,call);
 			}
 			audio_stream_set_rtcp_information(call->audiostream, cname, LINPHONE_RTCP_SDES_TOOL);
+			
+			if (stream->proto == SalProtoRtpSavp) {
+				const SalStreamDescription *local_st_desc=sal_media_description_find_stream(call->localdesc,
+	    					SalProtoRtpSavp,SalAudio);
+				audio_stream_enable_strp(
+					call->audiostream, 
+					stream->crypto[0].algo,
+					local_st_desc->crypto[find_crypto_index_from_tag(local_st_desc->crypto,stream->crypto[0].tag)].master_key,
+					stream->crypto[0].master_key);
+				call->audiostream_encrypted=TRUE;
+			}else call->audiostream_encrypted=FALSE;
 			if (call->params.in_conference){
 				/*transform the graph to connect it to the conference filter */
-				linphone_call_add_to_conf(call);
+				bool_t mute=stream->dir==SalStreamRecvOnly;
+				linphone_call_add_to_conf(call, mute);
 			}
+			call->current_params.in_conference=call->params.in_conference;
 		}else ms_warning("No audio stream accepted ?");
 	}
 }
@@ -1078,8 +1165,14 @@ static void linphone_call_start_video_stream(LinphoneCall *call, const char *cna
 #ifdef VIDEO_ENABLED
 	LinphoneCore *lc=call->core;
 	int used_pt=-1;
+	/* look for savp stream first */
 	const SalStreamDescription *vstream=sal_media_description_find_stream(call->resultdesc,
-		    					SalProtoRtpAvp,SalVideo);
+	    					SalProtoRtpSavp,SalVideo);
+	/* no savp audio stream, use avp */
+	if (!vstream)
+		vstream=sal_media_description_find_stream(call->resultdesc,
+	    					SalProtoRtpAvp,SalVideo);
+	    					
 	/* shutdown preview */
 	if (lc->previewstream!=NULL) {
 		video_preview_stop(lc->previewstream);
@@ -1136,6 +1229,21 @@ static void linphone_call_start_video_stream(LinphoneCall *call, const char *cna
 					used_pt, lc->rtp_conf.audio_jitt_comp, cam);
 				video_stream_set_rtcp_information(call->videostream, cname,LINPHONE_RTCP_SDES_TOOL);
 			}
+			
+			if (vstream->proto == SalProtoRtpSavp) {
+				const SalStreamDescription *local_st_desc=sal_media_description_find_stream(call->localdesc,
+	    					SalProtoRtpSavp,SalVideo);
+	    					
+				video_stream_enable_strp(
+					call->videostream, 
+					vstream->crypto[0].algo,
+					local_st_desc->crypto[0].master_key, 
+					vstream->crypto[0].master_key
+					);
+				call->videostream_encrypted=TRUE;
+			}else{
+				call->videostream_encrypted=FALSE;
+			}
 		}else ms_warning("No video stream accepted.");
 	}else{
 		ms_warning("No valid video stream defined.");
@@ -1147,7 +1255,7 @@ void linphone_call_start_media_streams(LinphoneCall *call, bool_t all_inputs_mut
 	LinphoneCore *lc=call->core;
 	LinphoneAddress *me=linphone_core_get_primary_contact_parsed(lc);
 	char *cname;
-	bool_t use_arc;
+	bool_t use_arc=linphone_core_adaptive_rate_control_enabled(lc);
 #ifdef VIDEO_ENABLED
 	const SalStreamDescription *vstream=sal_media_description_find_stream(call->resultdesc,
 		    					SalProtoRtpAvp,SalVideo);
@@ -1158,8 +1266,6 @@ void linphone_call_start_media_streams(LinphoneCall *call, bool_t all_inputs_mut
 		ms_fatal("start_media_stream() called without prior init !");
 		return;
 	}
-	call->current_params = call->params;
-	if (call->media_start_time==0) call->media_start_time=time(NULL);
 	cname=linphone_address_as_string_uri_only(me);
 
 #if defined(VIDEO_ENABLED)
@@ -1177,11 +1283,19 @@ void linphone_call_start_media_streams(LinphoneCall *call, bool_t all_inputs_mut
 	call->playing_ringbacktone=send_ringbacktone;
 	call->up_bw=linphone_core_get_upload_bandwidth(lc);
 
-	if (ortp_zrtp_available()) {
+	if (call->params.media_encryption==LinphoneMediaEncryptionZRTP) {
 		OrtpZrtpParams params;
-		params.zid=get_hexa_zrtp_identifier(lc);
+		/*will be set later when zrtp is activated*/
+		call->current_params.media_encryption=LinphoneMediaEncryptionNone;
+		
 		params.zid_file=lc->zrtp_secrets_cache;
 		audio_stream_enable_zrtp(call->audiostream,&params);
+	}else if (call->params.media_encryption==LinphoneMediaEncryptionSRTP){
+		call->current_params.media_encryption=linphone_call_are_all_streams_encrypted(call) ?
+			LinphoneMediaEncryptionSRTP : LinphoneMediaEncryptionNone;
+		/*also reflect the change if the "wished" params, in order to avoid to propose SAVP again
+		 * further in the call, for example during pause,resume, conferencing reINVITEs*/
+		call->params.media_encryption=call->current_params.media_encryption;
 	}
 
 	goto end;
@@ -1205,7 +1319,7 @@ void linphone_call_stop_media_streams(LinphoneCall *call){
 			const char *state_str=NULL;
 			ms_filter_call_method(call->audiostream->ec,MS_ECHO_CANCELLER_GET_STATE_STRING,&state_str);
 			if (state_str){
-				ms_message("Writing echo canceller state, %i bytes",(int)strlen(state_str));
+				ms_message("Writing echo canceler state, %i bytes",(int)strlen(state_str));
 				lp_config_set_string(call->core->config,"sound","ec_state",state_str);
 			}
 		}
@@ -1427,7 +1541,7 @@ void linphone_call_background_tasks(LinphoneCall *call, bool_t one_second_elapse
 		// mediastreamer queue.
 		audio_stream_iterate(call->audiostream);
 
-		if (call->audiostream->evq){
+		if (call->audiostream_app_evq){
 			OrtpEvent *ev;
 			while (NULL != (ev=ortp_ev_queue_get(call->audiostream_app_evq))){
 				OrtpEventType evt=ortp_event_get_type(ev);
