@@ -20,6 +20,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "linphonecore_utils.h"
 #include <ortp/zrtp.h>
 
+#ifdef TUNNEL_ENABLED
+#include "linphone_tunnel_manager.h"
+#endif
+
 extern "C" {
 #include "mediastreamer2/mediastream.h"
 }
@@ -675,6 +679,13 @@ extern "C" jboolean Java_org_linphone_core_LinphoneCoreImpl_isEchoCancellationEn
 	return linphone_core_echo_cancellation_enabled((LinphoneCore*)lc);
 }
 
+extern "C" jboolean Java_org_linphone_core_LinphoneCoreImpl_isEchoLimiterEnabled(JNIEnv*  env
+																			,jobject  thiz
+																			,jlong lc
+																			) {
+	return linphone_core_echo_limiter_enabled((LinphoneCore*)lc);
+}
+
 extern "C" jobject Java_org_linphone_core_LinphoneCoreImpl_getCurrentCall(JNIEnv*  env
 																			,jobject  thiz
 																			,jlong lc
@@ -725,6 +736,14 @@ extern "C" jboolean Java_org_linphone_core_LinphoneCoreImpl_isVideoEnabled(JNIEn
 																			,jlong lc) {
 	return linphone_core_video_enabled((LinphoneCore*)lc);
 }
+extern "C" void Java_org_linphone_core_LinphoneCoreImpl_setPlayFile(JNIEnv*  env
+																			,jobject  thiz
+																			,jlong lc
+																			,jstring jpath) {
+	const char* path = jpath?env->GetStringUTFChars(jpath, NULL):NULL;
+	linphone_core_set_play_file((LinphoneCore*)lc,path);
+	if (path) env->ReleaseStringUTFChars(jpath, path);
+}
 extern "C" void Java_org_linphone_core_LinphoneCoreImpl_setRing(JNIEnv*  env
 																			,jobject  thiz
 																			,jlong lc
@@ -775,7 +794,55 @@ extern "C" jint Java_org_linphone_core_LinphoneCoreImpl_startEchoCalibration(JNI
 
 }
 
+extern "C" int Java_org_linphone_core_LinphoneCoreImpl_getMediaEncryption(JNIEnv*  env
+																			,jobject  thiz
+																			,jlong lc
+																			) {
+	return (int)linphone_core_get_media_encryption((LinphoneCore*)lc);
+}
 
+extern "C" void Java_org_linphone_core_LinphoneCoreImpl_setMediaEncryption(JNIEnv*  env
+																			,jobject  thiz
+																			,jlong lc
+																			,int menc) {
+	linphone_core_set_media_encryption((LinphoneCore*)lc,(LinphoneMediaEncryption)menc);
+}
+
+extern "C" int Java_org_linphone_core_LinphoneCallParamsImpl_getMediaEncryption(JNIEnv*  env
+																			,jobject  thiz
+																			,jlong cp
+																			) {
+	return (int)linphone_call_params_get_media_encryption((LinphoneCallParams*)cp);
+}
+
+extern "C" jboolean Java_org_linphone_core_LinphoneCoreImpl_mediaEncryptionSupported(JNIEnv*  env
+																			,jobject  thiz
+																			,jlong lc, jint menc
+																			) {
+	return linphone_core_media_encryption_supported((LinphoneCore*)lc,(LinphoneMediaEncryption)menc);
+}
+
+extern "C" void Java_org_linphone_core_LinphoneCallParamsImpl_setMediaEncryption(JNIEnv*  env
+																			,jobject  thiz
+																			,jlong cp
+																			,int jmenc) {
+	linphone_call_params_set_media_encryption((LinphoneCallParams*)cp,(LinphoneMediaEncryption)jmenc);
+}
+
+extern "C" jboolean Java_org_linphone_core_LinphoneCoreImpl_getMediaEncryptionMandatory(JNIEnv*  env
+																			,jobject  thiz
+																			,jlong lc
+																			) {
+	return linphone_core_is_media_encryption_mandatory((LinphoneCore*)lc);
+}
+
+extern "C" void Java_org_linphone_core_LinphoneCoreImpl_setMediaEncryptionMandatory(JNIEnv*  env
+																			,jobject  thiz
+																			,jlong lc
+																			, jboolean yesno
+																			) {
+	linphone_core_set_media_encryption_mandatory((LinphoneCore*)lc, yesno);
+}
 
 //ProxyConfig
 
@@ -1389,8 +1456,8 @@ extern "C" jint Java_org_linphone_core_LinphoneCoreImpl_resumeCall(JNIEnv *env,j
 extern "C" jboolean Java_org_linphone_core_LinphoneCoreImpl_isInConference(JNIEnv *env,jobject thiz,jlong pCore) {
 	return linphone_core_is_in_conference((LinphoneCore *) pCore);
 }
-extern "C" void Java_org_linphone_core_LinphoneCoreImpl_enterConference(JNIEnv *env,jobject thiz,jlong pCore) {
-	linphone_core_enter_conference((LinphoneCore *) pCore);
+extern "C" jboolean Java_org_linphone_core_LinphoneCoreImpl_enterConference(JNIEnv *env,jobject thiz,jlong pCore) {
+	return 0 == linphone_core_enter_conference((LinphoneCore *) pCore);
 }
 extern "C" void Java_org_linphone_core_LinphoneCoreImpl_leaveConference(JNIEnv *env,jobject thiz,jlong pCore) {
 	linphone_core_leave_conference((LinphoneCore *) pCore);
@@ -1502,10 +1569,12 @@ extern "C" jboolean Java_org_linphone_core_LinphoneCallImpl_isAuthenticationToke
 	LinphoneCall *call = (LinphoneCall *) ptr;
 	return linphone_call_get_authentication_token_verified(call);
 }
-extern "C" jboolean Java_org_linphone_core_LinphoneCallImpl_areStreamsEncrypted(JNIEnv*  env,jobject thiz,jlong ptr) {
-	return linphone_call_are_all_streams_encrypted((LinphoneCall *) ptr);
+extern "C" void Java_org_linphone_core_LinphoneCallImpl_setAuthenticationTokenVerified(JNIEnv*  env,jobject thiz,jlong ptr,jboolean verified) {
+	LinphoneCall *call = (LinphoneCall *) ptr;
+	linphone_call_set_authentication_token_verified(call, verified);
 }
 
+
 extern "C" jboolean Java_org_linphone_core_LinphoneCoreImpl_soundResourcesLocked(JNIEnv* env,jobject thiz,jlong ptr){
 	return linphone_core_sound_resources_locked((LinphoneCore *) ptr);
 }
@@ -1523,3 +1592,48 @@ extern "C" void Java_org_linphone_LinphoneManager_hackSpeakerState(JNIEnv*  env,
 extern "C" jint Java_org_linphone_core_LinphoneCoreImpl_getMaxCalls(JNIEnv *env,jobject thiz,jlong pCore) {
 	return (jint) linphone_core_get_max_calls((LinphoneCore *) pCore);
 }
+extern "C" void Java_org_linphone_core_LinphoneCoreImpl_setMaxCalls(JNIEnv *env,jobject thiz,jlong pCore, jint max) {
+	linphone_core_set_max_calls((LinphoneCore *) pCore, (int) max);
+}
+
+extern "C" void Java_org_linphone_core_LinphoneCoreImpl_tunnelAddServerAndMirror(JNIEnv *env,jobject thiz,jlong pCore,
+		jstring jHost, jint port, jint mirror, jint delay) {
+#ifdef TUNNEL_ENABLED
+	LinphoneTunnelManager *tunnel=((LinphoneCore *) pCore)->tunnel; if (!tunnel) return;
+	const char* cHost=env->GetStringUTFChars(jHost, NULL);
+	linphone_tunnel_add_server_and_mirror(tunnel, cHost, port, mirror, delay);
+	env->ReleaseStringUTFChars(jHost, cHost);
+#endif
+}
+
+extern "C" void Java_org_linphone_core_LinphoneCoreImpl_tunnelAutoDetect(JNIEnv *env,jobject thiz,jlong pCore) {
+#ifdef TUNNEL_ENABLED
+	LinphoneTunnelManager *tunnel=((LinphoneCore *) pCore)->tunnel; if (!tunnel) return;
+	linphone_tunnel_auto_detect(tunnel);
+#endif
+}
+
+extern "C" void Java_org_linphone_core_LinphoneCoreImpl_tunnelCleanServers(JNIEnv *env,jobject thiz,jlong pCore) {
+#ifdef TUNNEL_ENABLED
+	LinphoneTunnelManager *tunnel=((LinphoneCore *) pCore)->tunnel; if (!tunnel) return;
+	linphone_tunnel_clean_servers(tunnel);
+#endif
+}
+
+extern "C" void Java_org_linphone_core_LinphoneCoreImpl_tunnelEnable(JNIEnv *env,jobject thiz,jlong pCore, jboolean enable) {
+#ifdef TUNNEL_ENABLED
+	LinphoneTunnelManager *tunnel=((LinphoneCore *) pCore)->tunnel; if (!tunnel) return;
+	linphone_tunnel_enable(tunnel, enable);
+#endif
+}
+
+extern "C" void Java_org_linphone_core_LinphoneCoreImpl_tunnelEnableLogs(JNIEnv *env,jobject thiz,jlong pCore, jboolean enable) {
+#ifdef TUNNEL_ENABLED
+	LinphoneTunnelManager *tunnel=((LinphoneCore *) pCore)->tunnel; if (!tunnel) return;
+	linphone_tunnel_enable_logs(tunnel, enable);
+#endif
+}
+
+extern "C" jboolean Java_org_linphone_core_LinphoneCoreImpl_isTunnelAvailable(JNIEnv *env,jobject thiz){
+	return linphone_core_tunnel_available();
+}
