@@ -24,8 +24,11 @@
 
 #ifndef _PRIVATE_H
 #define _PRIVATE_H
-
+#ifdef __cplusplus
+extern "C" {
+#endif
 #include "linphonecore.h"
+#include "linphone_tunnel_manager.h"
 #include "linphonecore_utils.h"
 #include "sal.h"
 
@@ -43,6 +46,10 @@
 #define PACKAGE_SOUND_DIR "."
 #endif
 
+#ifndef PACKAGE_DATA_DIR
+#define PACKAGE_DATA_DIR "."
+#endif
+
 #ifdef HAVE_GETTEXT
 #include <libintl.h>
 #ifndef _
@@ -57,14 +64,15 @@
 #endif
 #endif
 
-
 struct _LinphoneCallParams{
 	LinphoneCall *referer; /*in case this call creation is consecutive to an incoming transfer, this points to the original call */
 	int audio_bw; /* bandwidth limit for audio stream */
+	LinphoneMediaEncryption media_encryption;
 	bool_t has_video;
 	bool_t real_early_media; /*send real media even during early media (for outgoing calls)*/
 	bool_t in_conference; /*in conference mode */
 	bool_t pad;
+	
 };
 
 struct _LinphoneCall
@@ -400,6 +408,7 @@ struct _LinphoneConference{
 	MSAudioConference *conf;
 	AudioStream *local_participant;
 	MSAudioEndpoint *local_endpoint;
+	RtpProfile *local_dummy_profile;
 	bool_t local_muted;
 };
 
@@ -436,8 +445,7 @@ struct _LinphoneCore
 	int missed_calls;
 	VideoPreview *previewstream;
 	struct _MSEventQueue *msevq;
-	RtpTransport *a_rtp,*a_rtcp;
-	RtpTransport *v_rtp,*v_rtcp;
+	LinphoneRtpTransportFactories *rtptf;
 	MSList *bl_reqs;
 	MSList *subscribers;	/* unknown subscribers */
 	int minutes_away;
@@ -468,8 +476,11 @@ struct _LinphoneCore
 	int device_rotation;
 	bool_t ringstream_autorelease;
 	int max_calls;
+	LinphoneTunnelManager *tunnel;
 };
 
+LinphoneTunnelManager *linphone_core_tunnel_new(LinphoneCore *lc);
+
 bool_t linphone_core_can_we_add_call(LinphoneCore *lc);
 int linphone_core_add_call( LinphoneCore *lc, LinphoneCall *call);
 int linphone_core_del_call( LinphoneCore *lc, LinphoneCall *call);
@@ -514,11 +525,17 @@ void linphone_call_background_tasks(LinphoneCall *call, bool_t one_second_elapse
 void linphone_core_preempt_sound_resources(LinphoneCore *lc);
 /*conferencing subsystem*/
 void _post_configure_audio_stream(AudioStream *st, LinphoneCore *lc, bool_t muted);
-void linphone_call_add_to_conf(LinphoneCall *call);
+/* When a conference participant pause the conference he may send a music.
+ * We don't want to hear that music or to send it to the other participants.
+ * Use muted=yes to handle this case.
+ */
+void linphone_call_add_to_conf(LinphoneCall *call, bool_t muted);
 void linphone_call_remove_from_conf(LinphoneCall *call);
-void linphone_core_conference_check_uninit(LinphoneConference *ctx);
+void linphone_core_conference_check_uninit(LinphoneCore *lc);
 bool_t linphone_core_sound_resources_available(LinphoneCore *lc);
 
+void __linphone_core_invalidate_registers(LinphoneCore* lc);
+
 #define HOLD_OFF	(0)
 #define HOLD_ON		(1)
 
@@ -526,4 +543,9 @@ bool_t linphone_core_sound_resources_available(LinphoneCore *lc);
 #define NB_MAX_CALLS	(10)
 #endif
 void call_logs_write_to_config_file(LinphoneCore *lc);
+
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* _PRIVATE_H */
