@@ -31,10 +31,15 @@ Copyright (C) 2000  Simon MORLAT (simon.morlat@linphone.org)
 void linphone_proxy_config_write_all_to_config_file(LinphoneCore *lc){
 	MSList *elem;
 	int i;
+	if (!linphone_core_ready(lc)) return;
+	
 	for(elem=lc->sip_conf.proxies,i=0;elem!=NULL;elem=ms_list_next(elem),i++){
 		LinphoneProxyConfig *cfg=(LinphoneProxyConfig*)elem->data;
 		linphone_proxy_config_write_to_config_file(lc->config,cfg,i);
 	}
+	/*to ensure removed configs are erased:*/
+	linphone_proxy_config_write_to_config_file(lc->config,NULL,i);
+	lp_config_set_int(lc->config,"sip","default_proxy",linphone_core_get_default_proxy(lc,NULL));
 }
 
 void linphone_proxy_config_init(LinphoneProxyConfig *obj){
@@ -258,8 +263,12 @@ static char *guess_contact_for_register(LinphoneProxyConfig *obj){
 		linphone_address_set_display_name(contact,NULL);
 		
 		linphone_core_get_sip_transports(obj->lc,&tr);
-		if (tr.udp_port <= 0 && tr.tcp_port>0) {
-			sal_address_add_param(contact,"transport","tcp");
+		if (tr.udp_port <= 0) {
+			if (tr.tcp_port>0) {
+				sal_address_set_param(contact,"transport","tcp");
+			} else if (tr.tls_port>0) {
+				sal_address_set_param(contact,"transport","tls");
+			}
 		}
 		ret=linphone_address_as_string(contact);
 		linphone_address_destroy(contact);
@@ -269,10 +278,6 @@ static char *guess_contact_for_register(LinphoneProxyConfig *obj){
 }
 
 static void linphone_proxy_config_register(LinphoneProxyConfig *obj){
-	const char *id_str;
-
-	if (obj->reg_identity!=NULL) id_str=obj->reg_identity;
-	else id_str=linphone_core_get_primary_contact(obj->lc);
 	if (obj->reg_sendregister){
 		char *contact;
 		if (obj->op)
@@ -290,6 +295,17 @@ static void linphone_proxy_config_register(LinphoneProxyConfig *obj){
 	}
 }
 
+/**
+ * Refresh a proxy registration.
+ * This is useful if for example you resuming from suspend, thus IP address may have changed.
+**/
+void linphone_proxy_config_refresh_register(LinphoneProxyConfig *obj){
+	if (obj->reg_sendregister && obj->op){
+		obj->registered=FALSE;
+		sal_register_refresh(obj->op,obj->expires);
+	}
+}
+
 
 /**
  * Sets a dialing prefix to be automatically prepended when inviting a number with 
@@ -525,6 +541,7 @@ void linphone_core_remove_proxy_config(LinphoneCore *lc, LinphoneProxyConfig *cf
 	if (lc->default_proxy==cfg){
 		lc->default_proxy=NULL;
 	}
+	linphone_proxy_config_write_all_to_config_file(lc);
 }
 /**
  * Erase all proxies from config.
@@ -537,6 +554,7 @@ void linphone_core_clear_proxy_config(LinphoneCore *lc){
 		linphone_core_remove_proxy_config(lc,(LinphoneProxyConfig *)list->data);
 	}
 	ms_list_free(list);
+	linphone_proxy_config_write_all_to_config_file(lc);
 }
 /**
  * Sets the default proxy.
@@ -555,7 +573,8 @@ void linphone_core_set_default_proxy(LinphoneCore *lc, LinphoneProxyConfig *conf
 		}
 	}
 	lc->default_proxy=config;
-	
+	if (linphone_core_ready(lc))
+		lp_config_set_int(lc->config,"sip","default_proxy",linphone_core_get_default_proxy(lc,NULL));
 }	
 
 void linphone_core_set_default_proxy_index(LinphoneCore *lc, int index){
@@ -736,7 +755,7 @@ LinphoneAccountCreator *linphone_account_creator_new(struct _LinphoneCore *core,
 		return NULL;
 	}
 	if (!(sip_setup_get_capabilities(ss) & SIP_SETUP_CAP_ACCOUNT_MANAGER)){
-		ms_error("%s cannot manage accounts.");
+		ms_error("%s cannot manage accounts.",type);
 		return NULL;
 	}
 	obj=ms_new0(LinphoneAccountCreator,1);
