@@ -282,6 +282,7 @@ Sal * sal_init(){
 	sal->use_101=TRUE;
 	sal->reuse_authorization=FALSE;
 	sal->rootCa = 0;
+	sal->verify_server_certs=TRUE;
 	return sal;
 }
 
@@ -374,14 +375,16 @@ int sal_listen_port(Sal *ctx, const char *addr, int port, SalTransport tr, int i
 			snprintf(tlsCtx.root_ca_cert, sizeof(tlsCtx.client.cert), "%s", ctx->rootCa);
 			eXosip_set_tls_ctx(&tlsCtx);
 		}
+		eXosip_tls_verify_certificate(ctx->verify_server_certs);
 		break;
 	default:
 		ms_warning("unexpected proto, using datagram");
 	}
-
+#if 0
+	/* it does not work, exosip does not implement this option correctly*/
 	err=0;
-	eXosip_set_option(13,&err); /*13=EXOSIP_OPT_SRV_WITH_NAPTR, as it is an enum value, we can't use it unless we are sure of the
-					version of eXosip, which is not the case*/
+	eXosip_set_option(EXOSIP_OPT_DNS_CAPABILITIES,&err); /*0=no NAPTR */
+#endif
 	/*see if it looks like an IPv6 address*/
 	int use_rports = ctx->use_rports; // Copy char to int to avoid bad alignment
 	eXosip_set_option(EXOSIP_OPT_USE_RPORT,&use_rports);
@@ -440,12 +443,17 @@ void sal_use_101(Sal *ctx, bool_t use_101){
 	ctx->use_101=use_101;
 }
 
-void sal_root_ca(Sal* ctx, const char* rootCa) {
+void sal_set_root_ca(Sal* ctx, const char* rootCa) {
 	if (ctx->rootCa)
 		ms_free(ctx->rootCa);
 	ctx->rootCa = ms_strdup(rootCa);
 }
 
+void sal_verify_server_certificates(Sal *ctx, bool_t verify){
+	ctx->verify_server_certs=verify;
+	eXosip_tls_verify_certificate(verify);
+}
+
 static int extract_received_rport(osip_message_t *msg, const char **received, int *rportval,SalTransport* transport){
 	osip_via_t *via=NULL;
 	osip_generic_param_t *param=NULL;
@@ -454,7 +462,10 @@ static int extract_received_rport(osip_message_t *msg, const char **received, in
 	*rportval=5060;
 	*received=NULL;
 	osip_message_get_via(msg,0,&via);
-	if (!via) return -1;
+	if (!via) {
+		ms_warning("extract_received_rport(): no via.");
+		return -1;
+	}
 
 	*transport = sal_transport_parse(via->protocol);
 	
@@ -471,7 +482,10 @@ static int extract_received_rport(osip_message_t *msg, const char **received, in
 	osip_via_param_get_byname(via,"received",&param);
 	if (param) *received=param->gvalue;
 
-	if (rport==NULL && *received==NULL) return -1;
+	if (rport==NULL && *received==NULL){
+		ms_warning("extract_received_rport(): no rport and no received parameters.");
+		return -1;
+	}
 	return 0;
 }
 
@@ -514,12 +528,17 @@ static void sdp_process(SalOp *h){
 		 It should contains media parameters constraint from the remote offer, not our response*/
 		strcpy(h->result->addr,h->base.remote_media->addr);
 		h->result->bandwidth=h->base.remote_media->bandwidth;
+		
 		for(i=0;i<h->result->nstreams;++i){
 			if (h->result->streams[i].port>0){
 				strcpy(h->result->streams[i].addr,h->base.remote_media->streams[i].addr);
 				h->result->streams[i].ptime=h->base.remote_media->streams[i].ptime;
 				h->result->streams[i].bandwidth=h->base.remote_media->streams[i].bandwidth;
 				h->result->streams[i].port=h->base.remote_media->streams[i].port;
+				
+				if (h->result->streams[i].proto == SalProtoRtpSavp) {
+					h->result->streams[i].crypto[0] = h->base.remote_media->streams[i].crypto[0]; 
+				}
 			}
 		}
 	}
@@ -546,6 +565,9 @@ int sal_call(SalOp *h, const char *from, const char *to){
 	sal_op_set_from(h,from);
 	sal_op_set_to(h,to);
 	sal_exosip_fix_route(h);
+	
+	h->terminated = FALSE;
+
 	route = sal_op_get_route(h);
 	err=eXosip_call_build_initial_invite(&invite,to,from,route,"Phone call");
 	if (err!=0){
@@ -700,6 +722,7 @@ int sal_ping(SalOp *op, const char *from, const char *to){
 	
 	sal_op_set_from(op,from);
 	sal_op_set_to(op,to);
+
 	/*bug here: eXosip2 does not honor the route argument*/
 	eXosip_options_build_request (&options, sal_op_get_to(op),
 			sal_op_get_from(op),sal_op_get_route(op));
@@ -1657,7 +1680,7 @@ static bool_t fix_message_contact(SalOp *op, osip_message_t *request,osip_messag
 	if (extract_received_rport(last_answer,&received,&rport,&transport)==-1) return FALSE;
 	osip_message_get_contact(request,0,&ctt);
 	if (ctt == NULL) {
-		/*nothing to update*/
+		ms_warning("fix_message_contact(): no contact to update");
 		return FALSE;
 	}
 	if (ctt->url->host!=NULL){
@@ -1692,14 +1715,15 @@ static bool_t register_again_with_updated_contact(SalOp *op, osip_message_t *ori
 	if (extract_received_rport(last_answer,&received,&rport,&transport)==-1) return FALSE;
 	osip_message_get_contact(orig_request,0,&ctt);
 	osip_contact_to_str(ctt,&tmp);
-	ori_contact_address = sal_address_new((const char*)tmp);
+	ori_contact_address = sal_address_new(tmp);
 	
 	/*check if contact is up to date*/
 	if (strcmp(sal_address_get_domain(ori_contact_address),received) ==0 
 	&& sal_address_get_port_int(ori_contact_address) == rport
 	&& sal_address_get_transport(ori_contact_address) == transport) {
 		ms_message("Register has up to date contact, doing nothing.");
-		osip_free(tmp);     
+		osip_free(tmp);
+		sal_address_destroy(ori_contact_address);
 		return FALSE;
 	} else ms_message("contact do not match, need to update the register (%s with %s:%i;transport=%s)"
 		      ,tmp
@@ -1985,16 +2009,31 @@ static void register_set_contact(osip_message_t *msg, const char *contact){
 	osip_uri_uparam_add(ct->url,osip_strdup("line"),line);
 }
 
+static void sal_register_add_route(osip_message_t *msg, const char *proxy){
+	char tmp[256]={0};
+	snprintf(tmp,sizeof(tmp)-1,"<%s;lr>",proxy);
+	osip_message_set_route(msg,tmp);
+}
+
 int sal_register(SalOp *h, const char *proxy, const char *from, int expires){
 	osip_message_t *msg;
 	const char *contact=sal_op_get_contact(h);
-	
+
 	sal_op_set_route(h,proxy);
 	if (h->rid==-1){
+		SalAddress *from_parsed=sal_address_new(from);
+		char domain[256];
+		if (from_parsed==NULL) {
+			ms_warning("sal_register() bad from %s",from);
+			return -1;
+		}
+		snprintf(domain,sizeof(domain),"sip:%s",sal_address_get_domain(from_parsed));
+		sal_address_destroy(from_parsed);
 		eXosip_lock();
-		h->rid=eXosip_register_build_initial_register(from,proxy,NULL,expires,&msg);
+		h->rid=eXosip_register_build_initial_register(from,domain,NULL,expires,&msg);
 		if (msg){
 			if (contact) register_set_contact(msg,contact);
+			sal_register_add_route(msg,proxy);
 			sal_add_register(h->base.root,h);
 		}else{
 			ms_error("Could not build initial register.");
@@ -2003,7 +2042,8 @@ int sal_register(SalOp *h, const char *proxy, const char *from, int expires){
 		}
 	}else{
 		eXosip_lock();
-		eXosip_register_build_register(h->rid,expires,&msg);	
+		eXosip_register_build_register(h->rid,expires,&msg);
+		sal_register_add_route(msg,proxy);
 	}
 	eXosip_register_send_register(h->rid,msg);
 	eXosip_unlock();
@@ -2023,6 +2063,7 @@ int sal_register_refresh(SalOp *op, int expires){
 	eXosip_register_build_register(op->rid,expires,&msg);
 	if (msg!=NULL){
 		if (contact) register_set_contact(msg,contact);
+		sal_register_add_route(msg,sal_op_get_route(op));
 		eXosip_register_send_register(op->rid,msg);
 	}else ms_error("Could not build REGISTER refresh message.");
 	eXosip_unlock();
