@@ -70,7 +70,7 @@ static GdkPixbuf *create_status_picture(LinphoneOnlineStatus ss){
 void linphone_gtk_set_friend_status(GtkWidget *friendlist , LinphoneFriend * fid, const gchar *url, const gchar *status, const gchar *img){
 	GtkTreeIter iter;
 	LinphoneFriend *tmp=0;
-	gboolean found=FALSE;
+
 	GtkTreeModel *model=gtk_tree_view_get_model(GTK_TREE_VIEW(friendlist));
 	if (gtk_tree_model_get_iter_first(model,&iter)) {
 		do{
@@ -81,10 +81,9 @@ void linphone_gtk_set_friend_status(GtkWidget *friendlist , LinphoneFriend * fid
 				gtk_list_store_set(GTK_LIST_STORE(model),&iter,FRIEND_PRESENCE_STATUS,status,-1);
 				pixbuf = create_pixbuf(img);
 				if (pixbuf)
-				  {
-				    gtk_list_store_set(GTK_LIST_STORE(model),&iter,FRIEND_PRESENCE_IMG, pixbuf,-1);
-				  }
-				  found=TRUE;
+				{
+					gtk_list_store_set(GTK_LIST_STORE(model),&iter,FRIEND_PRESENCE_IMG, pixbuf,-1);
+				}
 			}
 		}while(gtk_tree_model_iter_next(model,&iter));
 	}
@@ -173,6 +172,72 @@ void linphone_gtk_my_presence_clicked(GtkWidget *button){
 	gtk_widget_show(menu);
 }
 
+static void icon_press_handler(GtkEntry *entry){
+	const char *text=gtk_entry_get_text(entry);
+	if (text && strlen(text)>0){
+		char *uri;
+		LinphoneFriend *lf;
+		linphone_core_interpret_friend_uri(linphone_gtk_get_core(),text,&uri);
+		if (uri==NULL){
+			return ;
+		}
+		lf=linphone_core_get_friend_by_address(linphone_gtk_get_core(),uri);
+		if (lf==NULL)
+			lf=linphone_friend_new_with_addr(uri);
+		if (lf!=NULL){
+			linphone_gtk_show_contact(lf);
+		}
+		ms_free(uri);
+	}
+}
+
+static void update_star(GtkEntry *entry, gboolean is_known){
+	GdkPixbuf *active,*starred,*unstarred;
+	active=gtk_entry_get_icon_pixbuf(entry,GTK_ENTRY_ICON_SECONDARY);
+	starred=g_object_get_data(G_OBJECT(entry),"starred_icon");
+	unstarred=g_object_get_data(G_OBJECT(entry),"unstarred_icon");
+	if (is_known && (active==unstarred)){
+		gtk_entry_set_icon_from_pixbuf(entry,GTK_ENTRY_ICON_SECONDARY,starred);
+		gtk_entry_set_icon_tooltip_text(GTK_ENTRY(entry),GTK_ENTRY_ICON_SECONDARY,NULL);
+	}else if ((!is_known) && (active==starred)){
+		gtk_entry_set_icon_tooltip_text(GTK_ENTRY(entry),GTK_ENTRY_ICON_SECONDARY,_("Add to addressbook"));
+		gtk_entry_set_icon_from_pixbuf(entry,GTK_ENTRY_ICON_SECONDARY,unstarred);
+	}
+}
+
+static void check_contact(GtkEditable *editable, LinphoneCore *lc){
+	char *tmp=gtk_editable_get_chars(editable,0,-1);
+	if (tmp!=NULL){
+		if (strlen(tmp)>0){
+			char *uri=NULL;
+			linphone_core_interpret_friend_uri(lc,tmp,&uri);
+			if (uri){
+				LinphoneFriend *lf=linphone_core_get_friend_by_address(lc,uri);
+				ms_free(uri);
+				if (lf) {
+					update_star(GTK_ENTRY(editable),TRUE);
+					g_free(tmp);
+					return;
+				}
+			}
+		}
+		g_free(tmp);
+	}
+	update_star(GTK_ENTRY(editable),FALSE);
+}
+
+static void linphone_gtk_init_bookmark_icon(void){
+	GtkWidget *mw=linphone_gtk_get_main_window();
+	GtkWidget *entry=linphone_gtk_get_widget(mw,"uribar");
+	GdkPixbuf *pbuf=create_pixbuf("contact_unstarred.png");
+	gtk_entry_set_icon_from_pixbuf(GTK_ENTRY(entry),GTK_ENTRY_ICON_SECONDARY,pbuf);
+	g_object_set_data_full(G_OBJECT(entry),"unstarred_icon",pbuf,g_object_unref);
+	pbuf=create_pixbuf("contact_starred.png");
+	g_object_set_data_full(G_OBJECT(entry),"starred_icon",pbuf,g_object_unref);
+	gtk_entry_set_icon_activatable(GTK_ENTRY(entry),GTK_ENTRY_ICON_SECONDARY,TRUE);
+	g_signal_connect(G_OBJECT(entry),"icon-release",(GCallback)icon_press_handler,NULL);
+	g_signal_connect(G_OBJECT(GTK_EDITABLE(entry)),"changed",(GCallback)check_contact,linphone_gtk_get_core());
+}
 
 static void linphone_gtk_friend_list_init(GtkWidget *friendlist)
 {
@@ -180,7 +245,8 @@ static void linphone_gtk_friend_list_init(GtkWidget *friendlist)
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
 	GtkTreeSelection *select;
-	
+
+	linphone_gtk_init_bookmark_icon();
 	
 	store = gtk_list_store_new(FRIEND_LIST_NCOL, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_STRING,  G_TYPE_POINTER,
 					G_TYPE_STRING, GDK_TYPE_PIXBUF);
@@ -278,6 +344,53 @@ void linphone_gtk_directory_search_button_clicked(GtkWidget *button){
 		linphone_gtk_get_widget(gtk_widget_get_toplevel(button),"directory_search_entry"));
 }
 
+static int get_friend_weight(const LinphoneFriend *lf){
+	int w=0;
+	switch(linphone_friend_get_status(lf)){
+		case LinphoneStatusOnline:
+			w+=1000;
+		break;
+		case LinphoneStatusOffline:
+			if (linphone_friend_get_send_subscribe(lf))
+				w+=100;
+		break;
+		default:
+			w+=500;
+		break;
+	}
+	return w;
+}
+
+static int friend_compare_func(const LinphoneFriend *lf1, const LinphoneFriend *lf2){
+	int w1,w2;
+	w1=get_friend_weight(lf1);
+	w2=get_friend_weight(lf2);
+	if (w1==w2){
+		const char *u1,*u2;
+		const LinphoneAddress *addr1,*addr2;
+		addr1=linphone_friend_get_address(lf1);
+		addr2=linphone_friend_get_address(lf2);
+		u1=linphone_address_get_username(addr1);
+		u2=linphone_address_get_username(addr2);
+		if (u1 && u2) return strcasecmp(u1,u2);
+		if (u1) return 1;
+		else return -1;
+	}
+	return w2-w1;
+}
+
+static MSList *sort_friend_list(const MSList *friends){
+	MSList *ret=NULL;
+	const MSList *elem;
+	LinphoneFriend *lf;
+
+	for(elem=friends;elem!=NULL;elem=elem->next){
+		lf=(LinphoneFriend*)elem->data;
+		ret=ms_list_insert_sorted(ret,lf,(MSCompareFunc)friend_compare_func);
+	}
+	return ret;
+}
+
 void linphone_gtk_show_friends(void){
 	GtkWidget *mw=linphone_gtk_get_main_window();
 	GtkWidget *friendlist=linphone_gtk_get_widget(mw,"contact_list");
@@ -289,6 +402,7 @@ void linphone_gtk_show_friends(void){
 	LinphoneCore *core=linphone_gtk_get_core();
 	const gchar *search=NULL;
 	gboolean online_only=FALSE,lookup=FALSE;
+	MSList *sorted;
 	
 	linphone_gtk_show_directory_search();
 
@@ -304,7 +418,9 @@ void linphone_gtk_show_friends(void){
 		lookup=FALSE;
 	else lookup=TRUE;
 
-	for(itf=linphone_core_get_friend_list(core);itf!=NULL;itf=ms_list_next(itf)){
+	sorted=sort_friend_list(linphone_core_get_friend_list(core));
+
+	for(itf=sorted;itf!=NULL;itf=ms_list_next(itf)){
 		LinphoneFriend *lf=(LinphoneFriend*)itf->data;
 		const LinphoneAddress *f_uri=linphone_friend_get_address(lf);
 		char *uri=linphone_address_as_string(f_uri);
@@ -319,14 +435,15 @@ void linphone_gtk_show_friends(void){
 		}
 		if (!online_only || (linphone_friend_get_status(lf)!=LinphoneStatusOffline)){
 			BuddyInfo *bi;
+			gboolean send_subscribe=linphone_friend_get_send_subscribe(lf);
 			if (name==NULL || name[0]=='\0') display=uri;
 			gtk_list_store_append(store,&iter);
 			gtk_list_store_set(store,&iter,FRIEND_NAME, display,
-					FRIEND_PRESENCE_STATUS, linphone_online_status_to_string(linphone_friend_get_status(lf)),
-					FRIEND_ID,lf,-1);
-			gtk_list_store_set(store,&iter,
-				FRIEND_PRESENCE_IMG, create_status_picture(linphone_friend_get_status(lf)),
-				-1);
+					FRIEND_PRESENCE_STATUS, 
+			        send_subscribe ? linphone_online_status_to_string(linphone_friend_get_status(lf)) : "",
+					FRIEND_ID,lf,
+			        FRIEND_PRESENCE_IMG, send_subscribe ? create_status_picture(linphone_friend_get_status(lf)) : NULL,
+			        -1); 
 			escaped=g_markup_escape_text(uri,-1);
 			gtk_list_store_set(store,&iter,FRIEND_SIP_ADDRESS,escaped,-1);
 			g_free(escaped);
@@ -342,9 +459,10 @@ void linphone_gtk_show_friends(void){
 		}
 		ms_free(uri);
 	}
+	ms_list_free(sorted);
 }
 
-void linphone_gtk_add_contact(void){
+void linphone_gtk_add_contact(){
 	GtkWidget *w=linphone_gtk_create_window("contact");
 	int presence_enabled=linphone_gtk_get_ui_config_int("use_subscribe_notify",1);
 	
