@@ -61,6 +61,7 @@ static void linphone_gtk_display_warning(LinphoneCore *lc, const char *warning);
 static void linphone_gtk_display_url(LinphoneCore *lc, const char *msg, const char *url);
 static void linphone_gtk_call_log_updated(LinphoneCore *lc, LinphoneCallLog *cl);
 static void linphone_gtk_call_state_changed(LinphoneCore *lc, LinphoneCall *call, LinphoneCallState cs, const char *msg);
+static void linphone_gtk_call_encryption_changed(LinphoneCore *lc, LinphoneCall *call, bool_t enabled, const char *token);
 static gboolean linphone_gtk_auto_answer(LinphoneCall *call);
 static void linphone_gtk_status_icon_set_blinking(gboolean val);
 
@@ -125,34 +126,35 @@ static GOptionEntry linphone_options[]={
 
 #ifndef WIN32
 #define CONFIG_FILE ".linphonerc"
+#define SECRETS_FILE ".linphone-zidcache"
 #else
 #define CONFIG_FILE "linphonerc"
+#define SECRETS_FILE "linphone-zidcache"
 #endif
 
 
-
-static char _config_file[1024];
-
-
-const char *linphone_gtk_get_config_file(){
+char *linphone_gtk_get_config_file(const char *filename){
+	const int path_max=1024;
+	char *config_file=g_malloc0(path_max);
+	if (filename==NULL) filename=CONFIG_FILE;
 	/*try accessing a local file first if exists*/
 	if (access(CONFIG_FILE,F_OK)==0){
-		snprintf(_config_file,sizeof(_config_file),"%s",CONFIG_FILE);
+		snprintf(config_file,path_max,"%s",filename);
 	}else{
 #ifdef WIN32
 		const char *appdata=getenv("APPDATA");
 		if (appdata){
-			snprintf(_config_file,sizeof(_config_file),"%s\\%s",appdata,LINPHONE_CONFIG_DIR);
-			CreateDirectory(_config_file,NULL);
-			snprintf(_config_file,sizeof(_config_file),"%s\\%s",appdata,LINPHONE_CONFIG_DIR "\\" CONFIG_FILE);
+			snprintf(config_file,path_max,"%s\\%s",appdata,LINPHONE_CONFIG_DIR);
+			CreateDirectory(config_file,NULL);
+			snprintf(config_file,path_max,"%s\\%s\\%s",appdata,LINPHONE_CONFIG_DIR,filename);
 		}
 #else
 		const char *home=getenv("HOME");
 		if (home==NULL) home=".";
-		snprintf(_config_file,sizeof(_config_file),"%s/%s",home,CONFIG_FILE);
+		snprintf(config_file,path_max,"%s/%s",home,filename);
 #endif
 	}
-	return _config_file;
+	return config_file;
 }
 
 
@@ -206,6 +208,7 @@ static const char *linphone_gtk_get_factory_config_file(){
 static void linphone_gtk_init_liblinphone(const char *config_file,
 		const char *factory_config_file) {
 	LinphoneCoreVTable vtable={0};
+	gchar *secrets_file=linphone_gtk_get_config_file(SECRETS_FILE);
 
 	vtable.call_state_changed=linphone_gtk_call_state_changed;
 	vtable.registration_state_changed=linphone_gtk_registration_state_changed;
@@ -220,10 +223,13 @@ static void linphone_gtk_init_liblinphone(const char *config_file,
 	vtable.text_received=linphone_gtk_text_received;
 	vtable.refer_received=linphone_gtk_refer_received;
 	vtable.buddy_info_updated=linphone_gtk_buddy_info_updated;
+	vtable.call_encryption_changed=linphone_gtk_call_encryption_changed;
 
 	linphone_core_set_user_agent("Linphone", LINPHONE_VERSION);
 	the_core=linphone_core_new(&vtable,config_file,factory_config_file,NULL);
 	linphone_core_set_waiting_callback(the_core,linphone_gtk_wait,NULL);
+	linphone_core_set_zrtp_secrets_file(the_core,secrets_file);
+	g_free(secrets_file);
 }
 
 
@@ -493,7 +499,7 @@ static gboolean linphone_gtk_iterate(LinphoneCore *lc){
 	static unsigned long previd=0;
 	static unsigned long preview_previd=0;
 	static gboolean in_iterate=FALSE;
-	
+
 	/*avoid reentrancy*/
 	if (in_iterate) return TRUE;
 	in_iterate=TRUE;
@@ -675,7 +681,11 @@ static void linphone_gtk_update_call_buttons(LinphoneCall *call){
 	gtk_widget_set_visible(button,!add_call);
 	
 	button=linphone_gtk_get_widget(mw,"add_call");
-	gtk_widget_set_sensitive(button,start_active);
+	if (linphone_core_sound_resources_locked(lc) || (call && linphone_call_get_state(call)==LinphoneCallIncomingReceived)) {
+		gtk_widget_set_sensitive(button,FALSE);
+	} else {
+		gtk_widget_set_sensitive(button,start_active);
+	}
 	gtk_widget_set_visible(button,add_call);
 	
 	gtk_widget_set_sensitive(linphone_gtk_get_widget(mw,"terminate_call"),stop_active);
@@ -1058,6 +1068,10 @@ static void linphone_gtk_call_state_changed(LinphoneCore *lc, LinphoneCall *call
 	linphone_gtk_update_call_buttons (call);
 }
 
+static void linphone_gtk_call_encryption_changed(LinphoneCore *lc, LinphoneCall *call, bool_t enabled, const char *token){
+	linphone_gtk_in_call_view_show_encryption(call);
+}
+
 static void update_registration_status(LinphoneProxyConfig *cfg, LinphoneRegistrationState rs){
 	GtkComboBox *box=GTK_COMBO_BOX(linphone_gtk_get_widget(linphone_gtk_get_main_window(),"identities"));
 	GtkTreeModel *model=gtk_combo_box_get_model(box);
@@ -1137,6 +1151,8 @@ void linphone_gtk_link_to_website(GtkWidget *item){
 
 #ifndef HAVE_GTK_OSX
 
+static GtkStatusIcon *icon=NULL;
+
 static void icon_popup_menu(GtkStatusIcon *status_icon, guint button, guint activate_time, gpointer user_data){
 	GtkWidget *menu=(GtkWidget*)g_object_get_data(G_OBJECT(status_icon),"menu");
 	gtk_menu_popup(GTK_MENU(menu),NULL,NULL,gtk_status_icon_position_menu,status_icon,button,activate_time);
@@ -1175,8 +1191,6 @@ static GtkWidget *create_icon_menu(){
 	return menu;
 }
 
-static GtkStatusIcon *icon=NULL;
-
 static void handle_icon_click() {
 	GtkWidget *mw=linphone_gtk_get_main_window();
 	if (!gtk_window_is_active((GtkWindow*)mw)) {
@@ -1245,6 +1259,13 @@ static void linphone_gtk_status_icon_set_blinking(gboolean val){
 #endif
 }
 
+void linphone_gtk_options_activate(GtkWidget *item){
+#ifndef HAVE_GTK_OSX
+	gtk_widget_set_visible(linphone_gtk_get_widget(linphone_gtk_get_main_window(),"quit_item"),
+		icon && !gtk_status_icon_is_embedded(icon));
+#endif
+}
+
 static void init_identity_combo(GtkComboBox *box){
 	GtkListStore *store;
 	GtkCellRenderer *r1,*r2;
@@ -1591,7 +1612,7 @@ int main(int argc, char *argv[]){
 #ifdef ENABLE_NLS
 	void *p;
 #endif
-	const char *config_file;
+	char *config_file;
 	const char *factory_config_file;
 	const char *lang;
 	GtkSettings *settings;
@@ -1603,7 +1624,7 @@ int main(int argc, char *argv[]){
 	
 	progpath = strdup(argv[0]);
 	
-	config_file=linphone_gtk_get_config_file();
+	config_file=linphone_gtk_get_config_file(NULL);
 	
 
 #ifdef WIN32
