@@ -18,6 +18,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #include "linphone.h"
+#include "linphone_tunnel_manager.h"
 
 typedef enum {
 	CAP_IGNORE,
@@ -803,6 +804,72 @@ void linphone_gtk_ui_level_toggled(GtkWidget *w) {
 	linphone_gtk_ui_level_adapt(top);
 }
 
+static void linphone_gtk_media_encryption_changed(GtkWidget *combo){
+	char *selected=gtk_combo_box_get_active_text(GTK_COMBO_BOX(combo));
+	LinphoneCore *lc=linphone_gtk_get_core();
+	if (selected!=NULL){
+		if (strcasecmp(selected,"SRTP")==0)
+			linphone_core_set_media_encryption(lc,LinphoneMediaEncryptionSRTP);
+		else if (strcasecmp(selected,"ZRTP")==0)
+			linphone_core_set_media_encryption(lc,LinphoneMediaEncryptionZRTP);
+		else linphone_core_set_media_encryption(lc,LinphoneMediaEncryptionNone);
+		g_free(selected);
+	}else g_warning("gtk_combo_box_get_active_text() returned NULL");
+}
+
+static void linphone_gtk_show_media_encryption(GtkWidget *pb){
+	LinphoneCore *lc=linphone_gtk_get_core();
+	GtkWidget *combo=linphone_gtk_get_widget(pb,"media_encryption_combo");
+	bool_t no_enc=TRUE;
+	int srtp_id=-1,zrtp_id=-1;
+	GtkTreeModel *model;
+	GtkListStore *store;
+	GtkTreeIter iter;
+	GtkCellRenderer *renderer=gtk_cell_renderer_text_new();
+	
+	model=GTK_TREE_MODEL((store=gtk_list_store_new(1,G_TYPE_STRING)));
+	gtk_combo_box_set_model(GTK_COMBO_BOX(combo),model);
+	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(combo),renderer,TRUE);
+	gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(combo),renderer,"text",0,NULL);
+	
+	gtk_list_store_append(store,&iter);
+	gtk_list_store_set(store,&iter,0,_("None"),-1);
+	
+	if (linphone_core_media_encryption_supported(lc,LinphoneMediaEncryptionSRTP)){
+		gtk_list_store_append(store,&iter);
+		gtk_list_store_set(store,&iter,0,_("SRTP"),-1);
+		srtp_id=1;
+		no_enc=FALSE;
+	}
+	if (linphone_core_media_encryption_supported(lc,LinphoneMediaEncryptionZRTP)){
+		gtk_list_store_append(store,&iter);
+		gtk_list_store_set(store,&iter,0,_("ZRTP"),-1);
+		no_enc=FALSE;
+		if (srtp_id!=-1) zrtp_id=2;
+		else zrtp_id=1;
+	}
+	if (no_enc){
+		/*hide this setting*/
+		gtk_widget_hide(combo);
+		gtk_widget_hide(linphone_gtk_get_widget(pb,"media_encryption_label"));
+	}else{
+		LinphoneMediaEncryption menc=linphone_core_get_media_encryption(lc);
+		switch(menc){
+			case LinphoneMediaEncryptionNone:
+				gtk_combo_box_set_active(GTK_COMBO_BOX(combo),0);
+			break;
+			case LinphoneMediaEncryptionSRTP:
+				if (srtp_id!=-1) gtk_combo_box_set_active(GTK_COMBO_BOX(combo),srtp_id);
+			break;
+			case LinphoneMediaEncryptionZRTP:
+				if (zrtp_id!=-1) gtk_combo_box_set_active(GTK_COMBO_BOX(combo),zrtp_id);
+			break;
+		}
+		g_signal_connect(G_OBJECT(combo),"changed",(GCallback)linphone_gtk_media_encryption_changed,NULL);
+	}
+	g_object_unref(G_OBJECT(model));
+}
+
 void linphone_gtk_show_parameters(void){
 	GtkWidget *pb=linphone_gtk_create_window("parameters");
 	LinphoneCore *lc=linphone_gtk_get_core();
@@ -841,6 +908,8 @@ void linphone_gtk_show_parameters(void){
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(linphone_gtk_get_widget(pb,"video_rtp_port")),
 				linphone_core_get_video_port(lc));
 
+	linphone_gtk_show_media_encryption(pb);
+	
 	tmp=linphone_core_get_nat_address(lc);
 	if (tmp) gtk_entry_set_text(GTK_ENTRY(linphone_gtk_get_widget(pb,"nat_address")),tmp);
 	tmp=linphone_core_get_stun_server(lc);
@@ -918,5 +987,88 @@ void linphone_gtk_show_parameters(void){
 
 	g_signal_connect(G_OBJECT(linphone_gtk_get_widget(pb,"proto_port")),"value-changed",(GCallback)linphone_gtk_update_my_port,NULL);
 	g_signal_connect(G_OBJECT(linphone_gtk_get_widget(pb,"proto_combo")),"changed",(GCallback)linphone_gtk_proto_changed,NULL);
+
+
+	if (linphone_core_tunnel_available(lc)){
+		gtk_widget_set_visible(GTK_WIDGET(linphone_gtk_get_widget(pb,"tunnel_edit_button")), TRUE);
+		gtk_widget_set_visible(GTK_WIDGET(linphone_gtk_get_widget(pb,"tunnel_label")), TRUE);
+	}
+
 	gtk_widget_show(pb);
 }
+
+
+void linphone_gtk_edit_tunnel_closed(GtkWidget *button){
+        GtkWidget *pb=gtk_widget_get_toplevel(button);
+        gtk_widget_destroy(pb);
+}
+
+#ifdef TUNNEL_ENABLED
+static void tunnel_get_server_host_and_port(LinphoneTunnelManager *tunnel, char *host, int size, int *port){
+	char *colon;
+        char *addresses=(char*)ms_strdup(linphone_tunnel_get_server_addresses(tunnel));
+	char *str1=addresses;
+        char *address=strtok(str1," "); // Not thread safe
+        if (!address) return;
+        colon=strchr(address, ':');
+        if (!colon) return;
+        *colon++='\0';
+	*port=atoi(colon);
+	memcpy(host,address,size);
+        ms_free(addresses);
+}
+#endif
+
+void linphone_gtk_edit_tunnel(GtkButton *button){
+#ifdef TUNNEL_ENABLED
+	LinphoneCore *lc=linphone_gtk_get_core();
+	GtkWidget *w=linphone_gtk_create_window("tunnel_config");
+	LinphoneTunnelManager *tunnel=linphone_tunnel_get(lc);
+	char host[50]={'\0'};
+	int port=0;
+	tunnel_get_server_host_and_port(tunnel, host, sizeof(host), &port);
+	LinphoneTunnelState state=linphone_tunnel_get_state(tunnel);
+
+	gtk_entry_set_text(GTK_ENTRY(linphone_gtk_get_widget(w,"host")),host);
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON(linphone_gtk_get_widget(w,"port")), port);
+
+	if (state == LinphoneTunnelEnabled){
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(linphone_gtk_get_widget(w,"radio_enable")),1);
+	} else{
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(linphone_gtk_get_widget(w,"radio_disable")),1);
+	}
+
+	g_object_weak_ref(G_OBJECT(w),(GWeakNotify)linphone_gtk_edit_tunnel_closed,w);
+
+    gtk_widget_show(w);
+#endif
+}
+
+void linphone_gtk_tunnel_ok(GtkButton *button){
+#ifdef TUNNEL_ENABLED
+	// Save information to config file
+	LinphoneCore *lc=linphone_gtk_get_core();
+	GtkWidget *w=gtk_widget_get_toplevel(GTK_WIDGET(button));
+	char address[50]={'\0'};
+	LinphoneTunnelManager *tunnel=linphone_tunnel_get(lc);
+
+	gint port = (gint)gtk_spin_button_get_value(GTK_SPIN_BUTTON(linphone_gtk_get_widget(w,"port")));
+	gboolean enabled=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(linphone_gtk_get_widget(w,"radio_enable")));
+	const char *host=gtk_entry_get_text(GTK_ENTRY(linphone_gtk_get_widget(w,"host")));
+
+	snprintf(address, sizeof address, "%s:%i", host, port);
+	linphone_tunnel_set_server_addresses(tunnel, address);
+	if (enabled){
+		linphone_tunnel_set_state(tunnel, LinphoneTunnelEnabled);
+	} else{
+		linphone_tunnel_set_state(tunnel,LinphoneTunnelDisabled);
+	}
+	linphone_core_update_tunnel(lc);
+	gtk_widget_destroy(w);
+#endif
+}
+
+
+void linphone_gtk_tunnel_cancel(GtkButton *button){
+
+}
