@@ -108,6 +108,8 @@ typedef enum MSFilterId{
 	MS_ANDROID_VIDEO_READ_ID,
 	MS_ANDROID_VIDEO_WRITE_ID,
 	MS_TONE_DETECTOR_ID,
+    MY_FILTER_ID,
+	MS_IOS_DISPLAY_ID,
 	MS_VP8_ENC_ID,
 	MS_VP8_DEC_ID,
 	MS_G722_ENC_ID,
