@@ -47,12 +47,13 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 void audio_stream_free(AudioStream *stream)
 {
 	if (stream->session!=NULL) {
-		rtp_session_unregister_event_queue(stream->session,stream->evq);
-		rtp_session_destroy(stream->session);
 		if (stream->ortpZrtpContext != NULL) {
 			ortp_zrtp_context_destroy(stream->ortpZrtpContext);
 			stream->ortpZrtpContext=NULL;
 		}
+		rtp_session_unregister_event_queue(stream->session,stream->evq);
+		rtp_session_destroy(stream->session);
+		
 	}
 	if (stream->evq) ortp_ev_queue_destroy(stream->evq);
 	if (stream->rtpsend!=NULL) ms_filter_destroy(stream->rtpsend);
@@ -144,7 +145,11 @@ MSTickerPrio __ms_get_default_prio(bool_t is_video){
 			return MS_TICKER_PRIO_REALTIME;
 		ms_error("Undefined priority %s", penv);
 	}
+#ifdef __linux
 	return MS_TICKER_PRIO_REALTIME;
+#else
+    return MS_TICKER_PRIO_HIGH;
+#endif
 }
 
 RtpSession * create_duplex_rtpsession( int locport, bool_t ipv6){
@@ -344,7 +349,7 @@ int audio_stream_start_full(AudioStream *stream, RtpProfile *profile, const char
 	stream->decoder=ms_filter_create_decoder(pt->mime_type);
 	if ((stream->encoder==NULL) || (stream->decoder==NULL)){
 		/* big problem: we have not a registered codec for this payload...*/
-		ms_error("mediastream.c: No decoder available for payload %i.",payload);
+		ms_error("audio_stream_start_full: No decoder or encoder available for payload %s.",pt->mime_type);
 		return -1;
 	}
 	if (ms_filter_has_method(stream->decoder, MS_FILTER_SET_RTP_PAYLOAD_PICKER)) {
@@ -515,14 +520,21 @@ void audio_stream_set_rtcp_information(AudioStream *st, const char *cname, const
 	}
 }
 
+// Pass NULL to stop playing
 void audio_stream_play(AudioStream *st, const char *name){
+	if (st->soundread == NULL) {
+		ms_warning("Cannot play file: the stream hasn't been started");
+		return;
+	}
 	if (ms_filter_get_id(st->soundread)==MS_FILE_PLAYER_ID){
 		ms_filter_call_method_noarg(st->soundread,MS_FILE_PLAYER_CLOSE);
-		ms_filter_call_method(st->soundread,MS_FILE_PLAYER_OPEN,(void*)name);
-		if (st->read_resampler){
-			audio_stream_configure_resampler(st->read_resampler,st->soundread,st->rtpsend);
+		if (name != NULL) {
+			ms_filter_call_method(st->soundread,MS_FILE_PLAYER_OPEN,(void*)name);
+			if (st->read_resampler){
+				audio_stream_configure_resampler(st->read_resampler,st->soundread,st->rtpsend);
+			}
+			ms_filter_call_method_noarg(st->soundread,MS_FILE_PLAYER_START);
 		}
-		ms_filter_call_method_noarg(st->soundread,MS_FILE_PLAYER_START);
 	}else{
 		ms_error("Cannot play file: the stream hasn't been started with"
 		" audio_stream_start_with_files");
@@ -814,7 +826,6 @@ MS2_PUBLIC float audio_stream_get_average_quality_rating(AudioStream *stream){
 	return 0;
 }
 
-
 void audio_stream_enable_zrtp(AudioStream *stream, OrtpZrtpParams *params){
 	stream->ortpZrtpContext=ortp_zrtp_context_new(stream->session, params);
 }
