@@ -67,19 +67,20 @@ MSFilter *ms_au_write_new(MSSndCard *card);
 
 static void show_format(const char *name, AudioStreamBasicDescription * deviceFormat)
 {
-	ms_message("Format for %s", name);
-	ms_message("mSampleRate = %g", deviceFormat->mSampleRate);
+	ms_debug("Format for %s", name);
+	ms_debug("mSampleRate = %g", deviceFormat->mSampleRate);
 	unsigned int fcc= ntohl(deviceFormat->mFormatID);
 	char outName[5];
 	memcpy(outName,&fcc,4);
 	outName[4] = 0;
-	ms_message("mFormatID = %s", outName);
-	ms_message("mFormatFlags = %08lX", deviceFormat->mFormatFlags);
-	ms_message("mBytesPerPacket = %ld", deviceFormat->mBytesPerPacket);
-	ms_message("mFramesPerPacket = %ld", deviceFormat->mFramesPerPacket);
-	ms_message("mChannelsPerFrame = %ld", deviceFormat->mChannelsPerFrame);
-	ms_message("mBytesPerFrame = %ld", deviceFormat->mBytesPerFrame);
-	ms_message("mBitsPerChannel = %ld", deviceFormat->mBitsPerChannel);
+	ms_debug("mFormatID = %s", outName);
+	ms_debug("mFormatFlags = %08lX", deviceFormat->mFormatFlags);
+	ms_debug("mBytesPerPacket = %ld", deviceFormat->mBytesPerPacket);
+	ms_debug("mFramesPerPacket = %ld", deviceFormat->mFramesPerPacket);
+	ms_debug("mChannelsPerFrame = %ld", deviceFormat->mChannelsPerFrame);
+	ms_debug("mBytesPerFrame = %ld", deviceFormat->mBytesPerFrame);
+	ms_debug("mBitsPerChannel = %ld", deviceFormat->mBitsPerChannel);
+	ms_message("Format for [%s] rate [%g] channels [%ld]", outName,deviceFormat->mSampleRate,deviceFormat->mChannelsPerFrame);
 }
 
 
@@ -184,10 +185,12 @@ static MSSndCard *ca_card_new(const char *name, const char * uidname, AudioDevic
 	
 	slen = sizeof(format);
 	d->rate=44100;
-	err = AudioDeviceGetProperty(dev, 0, cap & MS_SND_CARD_CAP_CAPTURE, kAudioDevicePropertyStreamFormat, &slen, &format);
-	if (err == kAudioHardwareNoError) {
-		show_format("output device", &format);
-		d->rate=format.mSampleRate;
+	if (d->dev != -1) {
+		err = AudioDeviceGetProperty(dev, 0, cap & MS_SND_CARD_CAP_CAPTURE, kAudioDevicePropertyStreamFormat, &slen, &format);
+		if (err == kAudioHardwareNoError) {
+			show_format("device", &format);
+			d->rate=format.mSampleRate;
+		}
 	}
 	return card;
 }
@@ -265,18 +268,28 @@ static void au_card_detect(MSSndCardManager * m)
 		ms_error("get kAudioHardwarePropertyDevices error %ld", err);
 		return;
 	}
+	/*first, add Default AudioUnit
+	does not work: why ?
+	*/
+	/*ms_snd_card_manager_add_card(m,ca_card_new("Default", "",-1, MS_SND_CARD_CAP_CAPTURE|MS_SND_CARD_CAP_PLAYBACK));
+	*/
+
 	count = slen / sizeof(AudioDeviceID);
 	for (i = 0; i < count; i++) {
 		MSSndCard *card;
 		char uidname[256]={0},devname[256]={0};
+		int card_capacity=0;
 		if (check_card_capability(devices[i],FALSE,devname,uidname,sizeof(uidname))){
-			card=ca_card_new(devname, uidname, devices[i], MS_SND_CARD_CAP_PLAYBACK);
-			ms_snd_card_manager_add_card(m, card);
+			card_capacity|=MS_SND_CARD_CAP_PLAYBACK;
 		}
 		if (check_card_capability(devices[i],TRUE,devname,uidname,sizeof(uidname))){
-			card=ca_card_new(devname, uidname, devices[i], MS_SND_CARD_CAP_CAPTURE);
+			card_capacity|=MS_SND_CARD_CAP_CAPTURE;
+		}
+		if (card_capacity) {
+			card=ca_card_new(devname, uidname, devices[i], card_capacity);
 			ms_snd_card_manager_add_card(m, card);
 		}
+
 	}
 }
 
@@ -351,7 +364,7 @@ static int audio_unit_open(AUCommon *d, bool_t is_read){
 	
 	// Get Default Input audio unit
 	desc.componentType = kAudioUnitType_Output;
-	desc.componentSubType = kAudioUnitSubType_HALOutput;
+	desc.componentSubType = d->dev!=-1?kAudioUnitSubType_HALOutput:kAudioUnitSubType_DefaultOutput;
 	desc.componentManufacturer = kAudioUnitManufacturer_Apple;
 	desc.componentFlags = 0;
 	desc.componentFlagsMask = 0;
@@ -371,31 +384,33 @@ static int audio_unit_open(AUCommon *d, bool_t is_read){
 	}
 	
 	param = is_read;
-	CHECK_AURESULT(AudioUnitSetProperty(d->au,
-				  kAudioOutputUnitProperty_EnableIO,
-				  kAudioUnitScope_Input,
-				  input_bus,
-				  &param,
-				  sizeof(UInt32)));
-	
-	param = !is_read;
-	CHECK_AURESULT(AudioUnitSetProperty(d->au,
-				  kAudioOutputUnitProperty_EnableIO,
-				  kAudioUnitScope_Output,
-				  output_bus,
-				  &param,
-				  sizeof(UInt32)));
-	
-	
-	
-	// Set the current device
-	CHECK_AURESULT(AudioUnitSetProperty(d->au,
-				  kAudioOutputUnitProperty_CurrentDevice,
-				  kAudioUnitScope_Global,
-				  output_bus,
-				  &d->dev,
-				  sizeof(AudioDeviceID)));
+	if (d->dev!=-1) {
+		CHECK_AURESULT(AudioUnitSetProperty(d->au,
+					  kAudioOutputUnitProperty_EnableIO,
+					  kAudioUnitScope_Input,
+					  input_bus,
+					  &param,
+					  sizeof(UInt32)));
+
+		param = !is_read;
+		CHECK_AURESULT(AudioUnitSetProperty(d->au,
+					  kAudioOutputUnitProperty_EnableIO,
+					  kAudioUnitScope_Output,
+					  output_bus,
+					  &param,
+					  sizeof(UInt32)));
+
+
+
+		// Set the current device
 	
+			CHECK_AURESULT(AudioUnitSetProperty(d->au,
+					  kAudioOutputUnitProperty_CurrentDevice,
+					  kAudioUnitScope_Global,
+					  output_bus,
+					  &d->dev,
+					  sizeof(AudioDeviceID)));
+	}
 
 	param=0;
 	CHECK_AURESULT(AudioUnitSetProperty(d->au,
