@@ -62,9 +62,8 @@ extern void libmsandroidopengldisplay_init(void);
 #include <dlfcn.h>
 #endif
 
-#if defined(__APPLE__) && !defined(__GNUC__)
-#import <Cocoa/Cocoa.h>
-#include <Foundation/Foundation.h>
+#ifdef __APPLE__
+   #include "TargetConditionals.h"
 #endif
 
 #ifdef ANDROID
@@ -75,6 +74,17 @@ extern void libmsandroidopengldisplay_init(void);
 static MSList *ms_plugins_loaded_list;
 #endif
 
+static unsigned int cpu_count = 1;
+
+unsigned int ms_get_cpu_count() {
+	return cpu_count;
+}
+
+void ms_set_cpu_count(unsigned int c) {
+	ms_message("CPU count set to %d", c);
+	cpu_count = c;
+}
+
 MSList *ms_list_new(void *data){
 	MSList *new_elem=(MSList *)ms_new(MSList,1);
 	new_elem->prev=new_elem->next=NULL;
@@ -495,9 +505,7 @@ static MSSndCardDesc * ms_snd_card_descs[]={
 #ifdef __MACSND_ENABLED__
 	&ca_card_desc,
 #endif
-#ifdef __MAC_AQ_ENABLED__
-	&aq_card_desc,
-#endif
+
 #ifdef __PULSEAUDIO_ENABLED__
 	&pulse_card_desc,
 #endif
@@ -505,6 +513,9 @@ static MSSndCardDesc * ms_snd_card_descs[]={
 #if TARGET_OS_IPHONE
 	&au_card_desc,
 #endif
+#ifdef __MAC_AQ_ENABLED__
+	&aq_card_desc,
+#endif
 #ifdef ANDROID
 	&msandroid_sound_card_desc,
 #endif
@@ -533,7 +544,7 @@ extern MSWebCamDesc ms_directx_cam_desc;
 extern MSWebCamDesc ms_dshow_cam_desc;
 #endif
 
-#ifdef __APPLE__
+#if TARGET_OS_MAC && !TARGET_OS_IPHONE
 extern MSWebCamDesc ms_v4m_cam_desc;
 #endif
 
@@ -545,6 +556,9 @@ extern MSWebCamDesc mire_desc;
 extern MSWebCamDesc ms_android_video_capture_desc;
 #endif
 
+#if TARGET_OS_IPHONE && !TARGET_IPHONE_SIMULATOR
+extern MSWebCamDesc ms_v4ios_cam_desc;
+#endif
 static MSWebCamDesc * ms_web_cam_descs[]={
 #ifdef HAVE_LINUX_VIDEODEV2_H
 	&v4l2_card_desc,
@@ -558,12 +572,15 @@ static MSWebCamDesc * ms_web_cam_descs[]={
 #if defined(__MINGW32__) || defined (HAVE_DIRECTSHOW)
 	&ms_dshow_cam_desc,
 #endif
-#ifdef __APPLE__
+#if TARGET_OS_MAC && !TARGET_OS_IPHONE
 	&ms_v4m_cam_desc,
 #endif
 #if defined (ANDROID)
 	&ms_android_video_capture_desc,
 #endif
+#if TARGET_OS_IPHONE &&  !TARGET_IPHONE_SIMULATOR
+	&ms_v4ios_cam_desc,
+#endif	
 #if !defined(NO_FFMPEG)
 	&mire_desc,
 	&static_image_desc,
