@@ -39,6 +39,8 @@ extern RtpSession * create_duplex_rtpsession( int locport, bool_t ipv6);
 /* this code is not part of the library itself, it is part of the mediastream program */
 void video_stream_free (VideoStream * stream)
 {
+	if (stream->ortpZrtpContext)
+		ortp_zrtp_context_destroy(stream->ortpZrtpContext);
 	if (stream->session!=NULL){
 		rtp_session_unregister_event_queue(stream->session,stream->evq);
 		rtp_session_destroy(stream->session);
@@ -270,6 +272,16 @@ static MSVideoSize get_compatible_size(MSVideoSize maxsize, MSVideoSize wished_s
 	return wished_size;
 }
 
+static MSVideoSize get_with_same_orientation(MSVideoSize size, MSVideoSize refsize){
+	if (ms_video_size_get_orientation(refsize)!=ms_video_size_get_orientation(size)){
+		int tmp;
+		tmp=size.width;
+		size.width=size.height;
+		size.height=tmp;
+	}
+	return size;
+}
+
 static void configure_video_source(VideoStream *stream){
 	MSVideoSize vsize,cam_vsize;
 	float fps=15;
@@ -292,7 +304,15 @@ static void configure_video_source(VideoStream *stream){
 		vsize=cam_vsize;
 		ms_message("Output video size adjusted to match camera resolution (%ix%i)\n",vsize.width,vsize.height);
 	} else if (cam_vsize.width*cam_vsize.height>vsize.width*vsize.height){
+#ifdef __arm__
+		ms_error("Camera is proposing a size bigger than encoder's suggested size (%ix%i > %ix%i) "
+		           "Using the camera size as fallback because cropping or resizing is not implemented for arm.",
+		           cam_vsize.width,cam_vsize.height,vsize.width,vsize.height);
+		vsize=cam_vsize;
+#else
+		vsize=get_with_same_orientation(vsize,cam_vsize);
 		ms_warning("Camera video size greater than encoder one. A scaling filter will be used!\n");
+#endif
 	}
 	ms_filter_call_method(stream->encoder,MS_FILTER_SET_VIDEO_SIZE,&vsize);
 	ms_filter_call_method(stream->encoder,MS_FILTER_GET_FPS,&fps);
@@ -467,6 +487,9 @@ int video_stream_start (VideoStream *stream, RtpProfile *profile, const char *re
 	/* create the ticker */
 	stream->ticker = ms_ticker_new();
 	ms_ticker_set_name(stream->ticker,"Video MSTicker");
+#ifdef __ios
+    ms_ticker_set_priority(stream->ticker,MS_TICKER_PRIO_HIGH);
+#endif
 	/* attach the graphs */
 	if (stream->source)
 		ms_ticker_attach (stream->ticker, stream->source);
@@ -605,11 +628,13 @@ void video_stream_use_preview_video_window(VideoStream *stream, bool_t yesno){
 }
 
 void video_stream_set_device_rotation(VideoStream *stream, int orientation){
+	MSFilter* target_filter;
+	
 	if (stream == 0)
 		return;
 
 	stream->device_orientation = orientation;
-	MSFilter* target_filter=stream->source;
+	target_filter=stream->source;
 	if (target_filter){
 		ms_filter_call_method(target_filter,MS_VIDEO_CAPTURE_SET_DEVICE_ORIENTATION,&orientation);
 	}
