@@ -102,7 +102,6 @@ typedef struct _MediastreamDatas {
 	int el_sustain;
 	float el_transmit_thres;
 	float ng_floorgain;
-	char * zrtp_id;
 	char * zrtp_secrets;
 	PayloadType *custom_pt;
 	int video_window_id;
@@ -170,7 +169,7 @@ const char *usage="mediastream --local <port> --remote <ip:port> \n"
 								"[ --el-sustain <(int)> (Time in milliseconds for which the attenuation is kept unchanged after) ]\n"
 								"[ --el-transmit-thres <(float) [0-1]> (TO BE DOCUMENTED) ]\n"
 								"[ --rc (enable adaptive rate control) ]\n"
-								"[ --zrtp <zid> <secrets file> (enable zrtp) ]\n"
+								"[ --zrtp <secrets file> (enable zrtp) ]\n"
 								"[ --verbose (most verbose messages) ]\n"
 								"[ --video-windows-id <video surface:preview surface>]\n"
 								"[ --srtp <local master_key> <remote master_key> (enable srtp, master key is generated if absent from comand line)\n"
@@ -208,7 +207,6 @@ int main(int argc, char * argv[]) {
 	cond=0;
 	pthread_join(main_thread,NULL);
 	return 0;
- 
 }
 static int _main(int argc, char * argv[])
 #endif
@@ -271,7 +269,6 @@ MediastreamDatas* init_default_args() {
 	args->el_transmit_thres=-1;
 	args->ng_floorgain=-1;
 	args->use_rc=FALSE;
-	args->zrtp_id=NULL;
 	args->zrtp_secrets=NULL;
 	args->custom_pt=NULL;
 	args->video_window_id = -1;
@@ -396,7 +393,6 @@ bool_t parse_args(int argc, char** argv, MediastreamDatas* out) {
 			i++;
 			out->el_transmit_thres=atof(argv[i]);
 		} else if (strcmp(argv[i],"--zrtp")==0){
-			out->zrtp_id=argv[++i];
 			out->zrtp_secrets=argv[++i];
 		} else if (strcmp(argv[i],"--verbose")==0){
 			out->is_verbose=TRUE;
@@ -435,6 +431,8 @@ bool_t parse_args(int argc, char** argv, MediastreamDatas* out) {
 
 void setup_media_streams(MediastreamDatas* args) {
 	/*create the rtp session */
+	MSWebCam *cam=NULL;
+
 	ortp_init();
 	if (args->is_verbose) {
 		ortp_set_log_level_mask(ORTP_DEBUG|ORTP_MESSAGE|ORTP_WARNING|ORTP_ERROR|ORTP_FATAL);
@@ -459,6 +457,10 @@ void setup_media_streams(MediastreamDatas* args) {
 	rtp_profile_set_payload(&av_profile,113,&payload_type_amr);
 	rtp_profile_set_payload(&av_profile,114,args->custom_pt);
 	rtp_profile_set_payload(&av_profile,115,&payload_type_lpc1015);
+#ifdef VIDEO_ENABLED
+#if defined (__ios) && defined (HAVE_X264)
+	libmsx264_init(); /*no plugin on IOS*/
+#endif
 	rtp_profile_set_payload(&av_profile,26,&payload_type_jpeg);
 	rtp_profile_set_payload(&av_profile,98,&payload_type_h263_1998);
 	rtp_profile_set_payload(&av_profile,97,&payload_type_theora);
@@ -467,9 +469,7 @@ void setup_media_streams(MediastreamDatas* args) {
 	rtp_profile_set_payload(&av_profile,102,&payload_type_h264);
 	rtp_profile_set_payload(&av_profile,103,&payload_type_vp8);
 	
-#ifdef VIDEO_ENABLED
 	args->video=NULL;
-	MSWebCam *cam=NULL;
 #endif
 	args->profile=rtp_profile_clone_full(&av_profile);
 	args->q=ortp_ev_queue_new();
@@ -551,12 +551,13 @@ void setup_media_streams(MediastreamDatas* args) {
 				}
 			}
 
-			if (args->zrtp_id != NULL) {
+            #ifndef TARGET_OS_IPHONE
+			if (args->zrtp_secrets != NULL) {
 				OrtpZrtpParams params;
-				params.zid=args->zrtp_id;
 				params.zid_file=args->zrtp_secrets;
 				audio_stream_enable_zrtp(args->audio,&params);
 			}
+            #endif
 
 			args->session=args->audio->session;
 		}
@@ -588,6 +589,7 @@ void setup_media_streams(MediastreamDatas* args) {
 		const char*  nowebcam = [[myBundle pathForResource:@"nowebcamCIF"ofType:@"jpg"] cStringUsingEncoding:[NSString defaultCStringEncoding]];
 		ms_static_image_set_default_image(nowebcam);
 #endif
+
 		video_stream_enable_adaptive_bitrate_control(args->video,args->use_rc);
 		if (args->camera)
 			cam=ms_web_cam_manager_get_cam(ms_web_cam_manager_get(),args->camera);
@@ -662,9 +664,10 @@ void run_interactive_loop(MediastreamDatas* args) {
 
 void run_non_interactive_loop(MediastreamDatas* args) {
 	rtp_session_register_event_queue(args->session,args->q);
-#if defined(_iOS) && defined(VIDEO_ENABLED)
-	ms_set_video_stream(args->video); /*for IOS*/
-#endif
+
+	#ifdef __ios
+	if (args->video) ms_set_video_stream(args->video); /*for IOS*/
+    #endif
 
 	while(cond)
 	{
