@@ -47,6 +47,7 @@ extern "C"{
 #define PAYLOAD_AUDIO_CONTINUOUS 0
 #define PAYLOAD_AUDIO_PACKETIZED 1
 #define PAYLOAD_VIDEO 2
+#define PAYLOAD_TEXT 4
 #define PAYLOAD_OTHER 3  /* ?? */
 
 struct _PayloadType
@@ -100,6 +101,9 @@ void payload_type_set_send_fmtp(PayloadType *pt, const char *fmtp);
 void payload_type_append_recv_fmtp(PayloadType *pt, const char *fmtp);
 void payload_type_append_send_fmtp(PayloadType *pt, const char *fmtp);
 
+#define payload_type_get_bitrate(pt)	((pt)->normal_bitrate)
+#define payload_type_get_rate(pt)		((pt)->clock_rate)
+#define payload_type_get_mime(pt)		((pt)->mime_type)
 
 bool_t fmtp_get_value(const char *fmtp, const char *param_name, char *result, size_t result_len);
 
@@ -167,18 +171,33 @@ VAR_DECLSPEC PayloadType payload_type_l16_stereo;
 VAR_DECLSPEC PayloadType payload_type_lpc1016;
 VAR_DECLSPEC PayloadType payload_type_g729;
 VAR_DECLSPEC PayloadType payload_type_g7231;
+VAR_DECLSPEC PayloadType payload_type_g7221;
+VAR_DECLSPEC PayloadType payload_type_g726_40;
+VAR_DECLSPEC PayloadType payload_type_g726_32;
+VAR_DECLSPEC PayloadType payload_type_g726_24;
+VAR_DECLSPEC PayloadType payload_type_g726_16;
+VAR_DECLSPEC PayloadType payload_type_aal2_g726_40;
+VAR_DECLSPEC PayloadType payload_type_aal2_g726_32;
+VAR_DECLSPEC PayloadType payload_type_aal2_g726_24;
+VAR_DECLSPEC PayloadType payload_type_aal2_g726_16;
 VAR_DECLSPEC PayloadType payload_type_gsm;
 VAR_DECLSPEC PayloadType payload_type_lpc;
 VAR_DECLSPEC PayloadType payload_type_lpc1015;
 VAR_DECLSPEC PayloadType payload_type_speex_nb;
 VAR_DECLSPEC PayloadType payload_type_speex_wb;
+VAR_DECLSPEC PayloadType payload_type_speex_uwb;
 VAR_DECLSPEC PayloadType payload_type_ilbc;
 VAR_DECLSPEC PayloadType payload_type_amr;
 VAR_DECLSPEC PayloadType payload_type_amrwb;
 VAR_DECLSPEC PayloadType payload_type_truespeech;
 VAR_DECLSPEC PayloadType payload_type_evrc0;
+VAR_DECLSPEC PayloadType payload_type_evrcb0;
+VAR_DECLSPEC PayloadType payload_type_silk_nb;	
+VAR_DECLSPEC PayloadType payload_type_silk_mb;
+VAR_DECLSPEC PayloadType payload_type_silk_wb;
+VAR_DECLSPEC PayloadType payload_type_silk_swb;
 
-/* video */
+	/* video */
 VAR_DECLSPEC PayloadType payload_type_mpv;
 VAR_DECLSPEC PayloadType payload_type_h261;
 VAR_DECLSPEC PayloadType payload_type_h263;
@@ -187,8 +206,18 @@ VAR_DECLSPEC PayloadType payload_type_h263_2000;
 VAR_DECLSPEC PayloadType payload_type_mp4v;
 VAR_DECLSPEC PayloadType payload_type_theora;
 VAR_DECLSPEC PayloadType payload_type_h264;
-VAR_DECLSPEC PayloadType payload_type_t140;
+VAR_DECLSPEC PayloadType payload_type_x_snow;
+VAR_DECLSPEC PayloadType payload_type_jpeg;
+VAR_DECLSPEC PayloadType payload_type_vp8;
 
+VAR_DECLSPEC PayloadType payload_type_g722;
+
+/* text */
+VAR_DECLSPEC PayloadType payload_type_t140;
+VAR_DECLSPEC PayloadType payload_type_t140_red;
+
+/* non standard file transfer over UDP */
+VAR_DECLSPEC PayloadType payload_type_x_udpftp;
 
 /* telephone-event */
 VAR_DECLSPEC PayloadType payload_type_telephone_event;
