@@ -541,7 +541,7 @@ PayloadType payload_type_vp8={
 	ZERO_PATTERN(NULL),
 	PATTERN_LENGTH(0),
 	NORMAL_BITRATE(256000),
-	MIME_TYPE ("VP8-DRAFT-0-3-2"),
+	MIME_TYPE ("VP8"),
 	CHANNELS(0)
 };
 
