@@ -30,9 +30,13 @@
 
 void jitter_control_init(JitterControl *ctl, int base_jiitt_time, PayloadType *pt);
 void jitter_control_enable_adaptive(JitterControl *ctl, bool_t val);
-void jitter_control_new_packet(JitterControl *ctl, uint32_t packet_ts, uint32_t cur_str_ts,
-								int32_t * slide, int32_t *safe_delay);
+void jitter_control_new_packet(JitterControl *ctl, uint32_t packet_ts, uint32_t cur_str_ts);
 #define jitter_control_adaptive_enabled(ctl) ((ctl)->adaptive)
 void jitter_control_set_payload(JitterControl *ctl, PayloadType *pt);
+void jitter_control_update_corrective_slide(JitterControl *ctl);
+
+static inline uint32_t jitter_control_get_compensated_timestamp(JitterControl *obj , uint32_t user_ts){
+	return (uint32_t)( (int64_t)user_ts+obj->slide-(int64_t)obj->adapt_jitt_comp_ts);
+}
 
 #endif
